Module: FtcApiV3Client

Defined in:
lib/ftc_api_v3_client/version.rb,
lib/ftc_api_v3_client.rb,
lib/ftc_api_v3_client/api_error.rb,
lib/ftc_api_v3_client/api_client.rb,
lib/ftc_api_v3_client/api/teams_api.rb,
lib/ftc_api_v3_client/configuration.rb,
lib/ftc_api_v3_client/api/events_api.rb,
lib/ftc_api_v3_client/api_model_base.rb,
lib/ftc_api_v3_client/api/leagues_api.rb,
lib/ftc_api_v3_client/api/regions_api.rb,
lib/ftc_api_v3_client/api/seasons_api.rb,
lib/ftc_api_v3_client/models/api_v3_team.rb,
lib/ftc_api_v3_client/models/api_v3_award.rb,
lib/ftc_api_v3_client/models/api_v3_event.rb,
lib/ftc_api_v3_client/models/api_v3_match.rb,
lib/ftc_api_v3_client/models/api_v3_stone.rb,
lib/ftc_api_v3_client/models/api_v3_teams.rb,
lib/ftc_api_v3_client/models/api_v3_awards.rb,
lib/ftc_api_v3_client/models/api_v3_events.rb,
lib/ftc_api_v3_client/models/api_v3_league.rb,
lib/ftc_api_v3_client/models/api_v3_region.rb,
lib/ftc_api_v3_client/models/api_v3_season.rb,
lib/ftc_api_v3_client/models/api_v3_leagues.rb,
lib/ftc_api_v3_client/models/api_v3_matches.rb,
lib/ftc_api_v3_client/models/api_v3_pit_map.rb,
lib/ftc_api_v3_client/models/api_v3_ranking.rb,
lib/ftc_api_v3_client/models/api_v3_regions.rb,
lib/ftc_api_v3_client/models/api_v3_seasons.rb,
lib/ftc_api_v3_client/models/api_v3_division.rb,
lib/ftc_api_v3_client/models/api_v3_rankings.rb,
lib/ftc_api_v3_client/models/api_v3_award_type.rb,
lib/ftc_api_v3_client/models/api_v3_event_type.rb,
lib/ftc_api_v3_client/models/api_v3_match_team.rb,
lib/ftc_api_v3_client/models/api_v3_coordinates.rb,
lib/ftc_api_v3_client/models/api_v3_simple_team.rb,
lib/ftc_api_v3_client/models/api_v3_team_avatar.rb,
lib/ftc_api_v3_client/models/api_v3_event_format.rb,
lib/ftc_api_v3_client/models/api_v3_playoff_type.rb,
lib/ftc_api_v3_client/models/api_v3_score_detail.rb,
lib/ftc_api_v3_client/models/api_v3_simple_event.rb,
lib/ftc_api_v3_client/models/api_v3_team_avatars.rb,
lib/ftc_api_v3_client/models/api_v3_team_details.rb,
lib/ftc_api_v3_client/models/api_v3_team_history.rb,
lib/ftc_api_v3_client/models/api_v3_match_details.rb,
lib/ftc_api_v3_client/models/api_v3_alliance_color.rb,
lib/ftc_api_v3_client/models/api_v3_alliance_match.rb,
lib/ftc_api_v3_client/models/api_v3_competing_type.rb,
lib/ftc_api_v3_client/models/api_v3_league_details.rb,
lib/ftc_api_v3_client/models/api_v3_match_alliance.rb,
lib/ftc_api_v3_client/models/api_v3_award_recipient.rb,
lib/ftc_api_v3_client/models/api_v3_cs_end_location.rb,
lib/ftc_api_v3_client/models/api_v3_ff_end_location.rb,
lib/ftc_api_v3_client/models/api_v3_pit_map_element.rb,
lib/ftc_api_v3_client/models/api_v3_playoff_ranking.rb,
lib/ftc_api_v3_client/models/api_v3_advancement_from.rb,
lib/ftc_api_v3_client/models/api_v3_cs_points_detail.rb,
lib/ftc_api_v3_client/models/api_v3_ff_auto_location.rb,
lib/ftc_api_v3_client/models/api_v3_ff_points_detail.rb,
lib/ftc_api_v3_client/models/api_v3_junction_element.rb,
lib/ftc_api_v3_client/models/api_v3_playoff_alliance.rb,
lib/ftc_api_v3_client/models/api_v3_playoff_rankings.rb,
lib/ftc_api_v3_client/models/api_v3_tournament_level.rb,
lib/ftc_api_v3_client/models/api_v3_ug_points_detail.rb,
lib/ftc_api_v3_client/models/api_v3_event_live_stream.rb,
lib/ftc_api_v3_client/models/api_v3_event_participant.rb,
lib/ftc_api_v3_client/models/api_v3_itd_auto_location.rb,
lib/ftc_api_v3_client/models/api_v3_itd_points_detail.rb,
lib/ftc_api_v3_client/models/api_v3_pit_map_cell_type.rb,
lib/ftc_api_v3_client/models/api_v3_playoff_alliances.rb,
lib/ftc_api_v3_client/models/api_v3_playoff_structure.rb,
lib/ftc_api_v3_client/models/api_v3_single_team_match.rb,
lib/ftc_api_v3_client/models/api_v3_advancement_status.rb,
lib/ftc_api_v3_client/models/api_v3_alliance_selection.rb,
lib/ftc_api_v3_client/models/api_v3_event_participants.rb,
lib/ftc_api_v3_client/models/api_v3_ug_wobble_location.rb,
lib/ftc_api_v3_client/models/api_v3_alliance_selections.rb,
lib/ftc_api_v3_client/models/api_v3_decode_score_detail.rb,
lib/ftc_api_v3_client/models/api_v3_itd_teleop_location.rb,
lib/ftc_api_v3_client/models/api_v3_remote_score_detail.rb,
lib/ftc_api_v3_client/models/api_v3_selection_operation.rb,
lib/ftc_api_v3_client/models/api_v3_team_season_history.rb,
lib/ftc_api_v3_client/models/api_v3_alliance_description.rb,
lib/ftc_api_v3_client/models/api_v3_decode_artifact_type.rb,
lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb,
lib/ftc_api_v3_client/models/api_v3_advancement_from_slot.rb,
lib/ftc_api_v3_client/models/api_v3_series_alliance_state.rb,
lib/ftc_api_v3_client/models/api_v3_skystone_score_detail.rb,
lib/ftc_api_v3_client/models/api_v3_alliance_match_details.rb,
lib/ftc_api_v3_client/models/api_v3_alliance_match_results.rb,
lib/ftc_api_v3_client/models/api_v3_cs_achievements_detail.rb,
lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb,
lib/ftc_api_v3_client/models/api_v3_playoff_match_alliance.rb,
lib/ftc_api_v3_client/models/api_v3_single_award_recipient.rb,
lib/ftc_api_v3_client/models/api_v3_skystone_points_detail.rb,
lib/ftc_api_v3_client/models/api_v3_ug_achievements_detail.rb,
lib/ftc_api_v3_client/models/api_v3_cs_remote_points_detail.rb,
lib/ftc_api_v3_client/models/api_v3_ff_remote_points_detail.rb,
lib/ftc_api_v3_client/models/api_v3_itd_achievements_detail.rb,
lib/ftc_api_v3_client/models/api_v3_power_play_score_detail.rb,
lib/ftc_api_v3_client/models/api_v3_remote_junction_element.rb,
lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb,
lib/ftc_api_v3_client/models/api_v3_power_play_auto_location.rb,
lib/ftc_api_v3_client/models/api_v3_power_play_points_detail.rb,
lib/ftc_api_v3_client/models/api_v3_team_event_participation.rb,
lib/ftc_api_v3_client/models/api_v3_center_stage_score_detail.rb,
lib/ftc_api_v3_client/models/api_v3_double_elims_bracket_half.rb,
lib/ftc_api_v3_client/models/api_v3_league_membership_details.rb,
lib/ftc_api_v3_client/models/api_v3_pit_map_label_orientation.rb,
lib/ftc_api_v3_client/models/api_v3_single_team_match_details.rb,
lib/ftc_api_v3_client/models/api_v3_single_team_match_results.rb,
lib/ftc_api_v3_client/models/api_v3_basic_alliance_description.rb,
lib/ftc_api_v3_client/models/api_v3_decode_achievements_detail.rb,
lib/ftc_api_v3_client/models/api_v3_into_the_deep_score_detail.rb,
lib/ftc_api_v3_client/models/api_v3_playoff_series_description.rb,
lib/ftc_api_v3_client/models/api_v3_ultimate_goal_score_detail.rb,
lib/ftc_api_v3_client/models/api_v3_alliance_match_participants.rb,
lib/ftc_api_v3_client/models/api_v3_decode_teleop_base_location.rb,
lib/ftc_api_v3_client/models/api_v3_freight_frenzy_score_detail.rb,
lib/ftc_api_v3_client/models/api_v3_series_alliance_description.rb,
lib/ftc_api_v3_client/models/api_v3_skystone_achievements_detail.rb,
lib/ftc_api_v3_client/models/api_v3_cs_remote_achievements_detail.rb,
lib/ftc_api_v3_client/models/api_v3_ff_remote_achievements_detail.rb,
lib/ftc_api_v3_client/models/api_v3_ug_remote_achievements_detail.rb,
lib/ftc_api_v3_client/models/api_v3_alliance_match_results_details.rb,
lib/ftc_api_v3_client/models/api_v3_power_play_achievements_detail.rb,
lib/ftc_api_v3_client/models/api_v3_power_play_remote_score_detail.rb,
lib/ftc_api_v3_client/models/api_v3_single_team_match_participants.rb,
lib/ftc_api_v3_client/models/api_v3_base_playoff_series_description.rb,
lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb,
lib/ftc_api_v3_client/models/api_v3_center_stage_remote_score_detail.rb,
lib/ftc_api_v3_client/models/api_v3_round_robin_alliance_description.rb,
lib/ftc_api_v3_client/models/api_v3_team_event_participation_details.rb,
lib/ftc_api_v3_client/models/api_v3_single_team_match_results_details.rb,
lib/ftc_api_v3_client/models/api_v3_ultimate_goal_remote_score_detail.rb,
lib/ftc_api_v3_client/models/api_v3_alliance_simple_match_participants.rb,
lib/ftc_api_v3_client/models/api_v3_freight_frenzy_remote_score_detail.rb,
lib/ftc_api_v3_client/models/api_v3_alliance_playoff_match_participants.rb,
lib/ftc_api_v3_client/models/api_v3_double_elimination_series_description.rb,
lib/ftc_api_v3_client/models/api_v3_power_play_remote_achievements_detail.rb

Overview

#FTC Scoring Data API

#THIS API IS CURRENTLY IN EARLY DEVELOPMENT AND MAY CHANGE WITHOUT WARNING. THIS PAGE WILL BE UPDATED ONCE THE API IS OFFICIALLY RELEASED. This API provides event and scoring data for FIRST Tech Challenge. Applications that present result data directly are encouraged to directly call this API rather than maintaining their own copies of the data. All endpoints are cached by our CDN and may return data up to one hour old for data that changes infrequently. During an event, data that changes frequently (e.g. match results and rankings) should not be more than 30 seconds old. NOTE: For developers who have integrated with the v2 API in the past, this is a policy shift, as previously developers were encouraged to maintain their own copy of relevant data. In the interest of providing the community with the most up-to-date data and reducing the burden for applications that are not performing their own analytics on event data, we are now encouraging directly integrating our API into websites and apps. Also note that all endpoints that accept a year argument now expect the year in which the FIRST Championship for that season is held. This is a change from the previous API and FTC-events website, which used the kickoff year. To report any issues, please report an issue here: https://github.com/FIRST-Tech-Challenge/scorekeeper/issues/new?template=api-bug-report.md To request additional data, please submit a feature request here: https://github.com/FIRST-Tech-Challenge/scorekeeper/issues/new?template=api-feature-request.md

The version of the OpenAPI document: v3

Generated by: https://openapi-generator.tech Generator version: 7.20.0

Defined Under Namespace

Modules: ApiV3AllianceDescription, ApiV3AllianceMatchParticipants, ApiV3BasePlayoffSeriesDescription, ApiV3Match, ApiV3MatchDetails, ApiV3RemoteScoreDetail, ApiV3ScoreDetail Classes: ApiClient, ApiError, ApiModelBase, ApiV3AdvancementFrom, ApiV3AdvancementFromSlot, ApiV3AdvancementStatus, ApiV3AllianceColor, ApiV3AllianceMatch, ApiV3AllianceMatchDetails, ApiV3AllianceMatchResults, ApiV3AllianceMatchResultsDetails, ApiV3AlliancePlayoffMatchParticipants, ApiV3AllianceSelection, ApiV3AllianceSelections, ApiV3AllianceSimpleMatchParticipants, ApiV3Award, ApiV3AwardRecipient, ApiV3AwardType, ApiV3Awards, ApiV3BasicAllianceDescription, ApiV3CenterStageRemoteScoreDetail, ApiV3CenterStageScoreDetail, ApiV3CompetingType, ApiV3Coordinates, ApiV3CsAchievementsDetail, ApiV3CsEndLocation, ApiV3CsPointsDetail, ApiV3CsRemoteAchievementsDetail, ApiV3CsRemotePointsDetail, ApiV3DecodeAchievementsDetail, ApiV3DecodeArtifactType, ApiV3DecodePointsDetail, ApiV3DecodeScoreDetail, ApiV3DecodeTeleopBaseLocation, ApiV3Division, ApiV3DoubleEliminationSeriesDescription, ApiV3DoubleElimsBracketHalf, ApiV3Event, ApiV3EventFormat, ApiV3EventLiveStream, ApiV3EventParticipant, ApiV3EventParticipants, ApiV3EventType, ApiV3Events, ApiV3FFAchievementsDetail, ApiV3FFAutoLocation, ApiV3FFEndLocation, ApiV3FFPointsDetail, ApiV3FFRemoteAchievementsDetail, ApiV3FFRemotePointsDetail, ApiV3FreightFrenzyRemoteScoreDetail, ApiV3FreightFrenzyScoreDetail, ApiV3IntoTheDeepScoreDetail, ApiV3ItdAchievementsDetail, ApiV3ItdAutoLocation, ApiV3ItdPointsDetail, ApiV3ItdTeleopLocation, ApiV3JunctionElement, ApiV3League, ApiV3LeagueDetails, ApiV3LeagueMembershipDetails, ApiV3Leagues, ApiV3MatchAlliance, ApiV3MatchTeam, ApiV3Matches, ApiV3PitMap, ApiV3PitMapCellType, ApiV3PitMapElement, ApiV3PitMapLabelOrientation, ApiV3PlayoffAlliance, ApiV3PlayoffAlliances, ApiV3PlayoffMatchAlliance, ApiV3PlayoffRanking, ApiV3PlayoffRankings, ApiV3PlayoffSeriesDescription, ApiV3PlayoffStructure, ApiV3PlayoffType, ApiV3PowerPlayAchievementsDetail, ApiV3PowerPlayAutoLocation, ApiV3PowerPlayPointsDetail, ApiV3PowerPlayRemoteAchievementsDetail, ApiV3PowerPlayRemotePointsDetail, ApiV3PowerPlayRemoteScoreDetail, ApiV3PowerPlayScoreDetail, ApiV3Ranking, ApiV3Rankings, ApiV3Region, ApiV3Regions, ApiV3RemoteJunctionElement, ApiV3RoundRobinAllianceDescription, ApiV3Season, ApiV3Seasons, ApiV3SelectionOperation, ApiV3SeriesAllianceDescription, ApiV3SeriesAllianceState, ApiV3SimpleEvent, ApiV3SimpleTeam, ApiV3SingleAwardRecipient, ApiV3SingleTeamMatch, ApiV3SingleTeamMatchDetails, ApiV3SingleTeamMatchParticipants, ApiV3SingleTeamMatchResults, ApiV3SingleTeamMatchResultsDetails, ApiV3SkystoneAchievementsDetail, ApiV3SkystonePointsDetail, ApiV3SkystoneScoreDetail, ApiV3Stone, ApiV3Team, ApiV3TeamAvatar, ApiV3TeamAvatars, ApiV3TeamDetails, ApiV3TeamEventParticipation, ApiV3TeamEventParticipationDetails, ApiV3TeamHistory, ApiV3TeamSeasonHistory, ApiV3Teams, ApiV3TournamentLevel, ApiV3UgAchievementsDetail, ApiV3UgPointsDetail, ApiV3UgRemoteAchievementsDetail, ApiV3UgRemotePointsDetail, ApiV3UgWobbleLocation, ApiV3UltimateGoalRemoteScoreDetail, ApiV3UltimateGoalScoreDetail, Configuration, EventsApi, LeaguesApi, RegionsApi, SeasonsApi, TeamsApi

Constant Summary collapse

VERSION =
'0.1.2'

Class Method Summary collapse

Class Method Details

.configureObject

Customize default settings for the SDK using block. FtcApiV3Client.configure do |config| config.username = "xxx" config.password = "xxx" end If no block given, return the default Configuration object.



165
166
167
168
169
170
171
# File 'lib/ftc_api_v3_client.rb', line 165

def configure
  if block_given?
    yield(Configuration.default)
  else
    Configuration.default
  end
end