Class: FtcApiV3Client::ApiV3DecodePointsDetail

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ApiV3DecodePointsDetail

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FtcApiV3Client::ApiV3DecodePointsDetail` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FtcApiV3Client::ApiV3DecodePointsDetail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'auto_leave_points')
    self.auto_leave_points = attributes[:'auto_leave_points']
  else
    self.auto_leave_points = nil
  end

  if attributes.key?(:'auto_artifact_points')
    self.auto_artifact_points = attributes[:'auto_artifact_points']
  else
    self.auto_artifact_points = nil
  end

  if attributes.key?(:'auto_pattern_points')
    self.auto_pattern_points = attributes[:'auto_pattern_points']
  else
    self.auto_pattern_points = nil
  end

  if attributes.key?(:'teleop_artifact_points')
    self.teleop_artifact_points = attributes[:'teleop_artifact_points']
  else
    self.teleop_artifact_points = nil
  end

  if attributes.key?(:'teleop_depot_points')
    self.teleop_depot_points = attributes[:'teleop_depot_points']
  else
    self.teleop_depot_points = nil
  end

  if attributes.key?(:'teleop_pattern_points')
    self.teleop_pattern_points = attributes[:'teleop_pattern_points']
  else
    self.teleop_pattern_points = nil
  end

  if attributes.key?(:'teleop_base_points')
    self.teleop_base_points = attributes[:'teleop_base_points']
  else
    self.teleop_base_points = nil
  end

  if attributes.key?(:'auto_points')
    self.auto_points = attributes[:'auto_points']
  else
    self.auto_points = nil
  end

  if attributes.key?(:'teleop_points')
    self.teleop_points = attributes[:'teleop_points']
  else
    self.teleop_points = nil
  end

  if attributes.key?(:'foul_points_committed')
    self.foul_points_committed = attributes[:'foul_points_committed']
  else
    self.foul_points_committed = nil
  end

  if attributes.key?(:'pre_foul_total')
    self.pre_foul_total = attributes[:'pre_foul_total']
  else
    self.pre_foul_total = nil
  end

  if attributes.key?(:'movement_rp')
    self.movement_rp = attributes[:'movement_rp']
  else
    self.movement_rp = nil
  end

  if attributes.key?(:'goal_rp')
    self.goal_rp = attributes[:'goal_rp']
  else
    self.goal_rp = nil
  end

  if attributes.key?(:'pattern_rp')
    self.pattern_rp = attributes[:'pattern_rp']
  else
    self.pattern_rp = nil
  end

  if attributes.key?(:'adjust_points')
    self.adjust_points = attributes[:'adjust_points']
  else
    self.adjust_points = nil
  end
end

Instance Attribute Details

#adjust_pointsObject

Used to indicate the winner in double-red-card playoff matches



47
48
49
# File 'lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb', line 47

def adjust_points
  @adjust_points
end

#auto_artifact_pointsObject

Returns the value of attribute auto_artifact_points.



20
21
22
# File 'lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb', line 20

def auto_artifact_points
  @auto_artifact_points
end

#auto_leave_pointsObject

Returns the value of attribute auto_leave_points.



18
19
20
# File 'lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb', line 18

def auto_leave_points
  @auto_leave_points
end

#auto_pattern_pointsObject

Returns the value of attribute auto_pattern_points.



22
23
24
# File 'lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb', line 22

def auto_pattern_points
  @auto_pattern_points
end

#auto_pointsObject

Returns the value of attribute auto_points.



32
33
34
# File 'lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb', line 32

def auto_points
  @auto_points
end

#foul_points_committedObject

Returns the value of attribute foul_points_committed.



36
37
38
# File 'lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb', line 36

def foul_points_committed
  @foul_points_committed
end

#goal_rpObject

Returns the value of attribute goal_rp.



42
43
44
# File 'lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb', line 42

def goal_rp
  @goal_rp
end

#movement_rpObject

Returns the value of attribute movement_rp.



40
41
42
# File 'lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb', line 40

def movement_rp
  @movement_rp
end

#pattern_rpObject

Returns the value of attribute pattern_rp.



44
45
46
# File 'lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb', line 44

def pattern_rp
  @pattern_rp
end

#pre_foul_totalObject

Returns the value of attribute pre_foul_total.



38
39
40
# File 'lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb', line 38

def pre_foul_total
  @pre_foul_total
end

#teleop_artifact_pointsObject

Returns the value of attribute teleop_artifact_points.



24
25
26
# File 'lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb', line 24

def teleop_artifact_points
  @teleop_artifact_points
end

#teleop_base_pointsObject

Returns the value of attribute teleop_base_points.



30
31
32
# File 'lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb', line 30

def teleop_base_points
  @teleop_base_points
end

#teleop_depot_pointsObject

Returns the value of attribute teleop_depot_points.



26
27
28
# File 'lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb', line 26

def teleop_depot_points
  @teleop_depot_points
end

#teleop_pattern_pointsObject

Returns the value of attribute teleop_pattern_points.



28
29
30
# File 'lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb', line 28

def teleop_pattern_points
  @teleop_pattern_points
end

#teleop_pointsObject

Returns the value of attribute teleop_points.



34
35
36
# File 'lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb', line 34

def teleop_points
  @teleop_points
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb', line 50

def self.attribute_map
  {
    :'auto_leave_points' => :'autoLeavePoints',
    :'auto_artifact_points' => :'autoArtifactPoints',
    :'auto_pattern_points' => :'autoPatternPoints',
    :'teleop_artifact_points' => :'teleopArtifactPoints',
    :'teleop_depot_points' => :'teleopDepotPoints',
    :'teleop_pattern_points' => :'teleopPatternPoints',
    :'teleop_base_points' => :'teleopBasePoints',
    :'auto_points' => :'autoPoints',
    :'teleop_points' => :'teleopPoints',
    :'foul_points_committed' => :'foulPointsCommitted',
    :'pre_foul_total' => :'preFoulTotal',
    :'movement_rp' => :'movementRP',
    :'goal_rp' => :'goalRP',
    :'pattern_rp' => :'patternRP',
    :'adjust_points' => :'adjustPoints'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
# File 'lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb', line 491

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
# File 'lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb', line 102

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb', line 81

def self.openapi_types
  {
    :'auto_leave_points' => :'Integer',
    :'auto_artifact_points' => :'Integer',
    :'auto_pattern_points' => :'Integer',
    :'teleop_artifact_points' => :'Integer',
    :'teleop_depot_points' => :'Integer',
    :'teleop_pattern_points' => :'Integer',
    :'teleop_base_points' => :'Integer',
    :'auto_points' => :'Integer',
    :'teleop_points' => :'Integer',
    :'foul_points_committed' => :'Integer',
    :'pre_foul_total' => :'Integer',
    :'movement_rp' => :'Boolean',
    :'goal_rp' => :'Boolean',
    :'pattern_rp' => :'Boolean',
    :'adjust_points' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
# File 'lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb', line 456

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      auto_leave_points == o.auto_leave_points &&
      auto_artifact_points == o.auto_artifact_points &&
      auto_pattern_points == o.auto_pattern_points &&
      teleop_artifact_points == o.teleop_artifact_points &&
      teleop_depot_points == o.teleop_depot_points &&
      teleop_pattern_points == o.teleop_pattern_points &&
      teleop_base_points == o.teleop_base_points &&
      auto_points == o.auto_points &&
      teleop_points == o.teleop_points &&
      foul_points_committed == o.foul_points_committed &&
      pre_foul_total == o.pre_foul_total &&
      movement_rp == o.movement_rp &&
      goal_rp == o.goal_rp &&
      pattern_rp == o.pattern_rp &&
      adjust_points == o.adjust_points
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


478
479
480
# File 'lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb', line 478

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



484
485
486
# File 'lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb', line 484

def hash
  [auto_leave_points, auto_artifact_points, auto_pattern_points, teleop_artifact_points, teleop_depot_points, teleop_pattern_points, teleop_base_points, auto_points, teleop_points, foul_points_committed, pre_foul_total, movement_rp, goal_rp, pattern_rp, adjust_points].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb', line 216

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @auto_leave_points.nil?
    invalid_properties.push('invalid value for "auto_leave_points", auto_leave_points cannot be nil.')
  end

  if @auto_artifact_points.nil?
    invalid_properties.push('invalid value for "auto_artifact_points", auto_artifact_points cannot be nil.')
  end

  if @auto_pattern_points.nil?
    invalid_properties.push('invalid value for "auto_pattern_points", auto_pattern_points cannot be nil.')
  end

  if @teleop_artifact_points.nil?
    invalid_properties.push('invalid value for "teleop_artifact_points", teleop_artifact_points cannot be nil.')
  end

  if @teleop_depot_points.nil?
    invalid_properties.push('invalid value for "teleop_depot_points", teleop_depot_points cannot be nil.')
  end

  if @teleop_pattern_points.nil?
    invalid_properties.push('invalid value for "teleop_pattern_points", teleop_pattern_points cannot be nil.')
  end

  if @teleop_base_points.nil?
    invalid_properties.push('invalid value for "teleop_base_points", teleop_base_points cannot be nil.')
  end

  if @auto_points.nil?
    invalid_properties.push('invalid value for "auto_points", auto_points cannot be nil.')
  end

  if @teleop_points.nil?
    invalid_properties.push('invalid value for "teleop_points", teleop_points cannot be nil.')
  end

  if @foul_points_committed.nil?
    invalid_properties.push('invalid value for "foul_points_committed", foul_points_committed cannot be nil.')
  end

  if @pre_foul_total.nil?
    invalid_properties.push('invalid value for "pre_foul_total", pre_foul_total cannot be nil.')
  end

  if @movement_rp.nil?
    invalid_properties.push('invalid value for "movement_rp", movement_rp cannot be nil.')
  end

  if @goal_rp.nil?
    invalid_properties.push('invalid value for "goal_rp", goal_rp cannot be nil.')
  end

  if @pattern_rp.nil?
    invalid_properties.push('invalid value for "pattern_rp", pattern_rp cannot be nil.')
  end

  if @adjust_points.nil?
    invalid_properties.push('invalid value for "adjust_points", adjust_points cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



513
514
515
516
517
518
519
520
521
522
523
524
525
# File 'lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb', line 513

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/ftc_api_v3_client/models/api_v3_decode_points_detail.rb', line 284

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @auto_leave_points.nil?
  return false if @auto_artifact_points.nil?
  return false if @auto_pattern_points.nil?
  return false if @teleop_artifact_points.nil?
  return false if @teleop_depot_points.nil?
  return false if @teleop_pattern_points.nil?
  return false if @teleop_base_points.nil?
  return false if @auto_points.nil?
  return false if @teleop_points.nil?
  return false if @foul_points_committed.nil?
  return false if @pre_foul_total.nil?
  return false if @movement_rp.nil?
  return false if @goal_rp.nil?
  return false if @pattern_rp.nil?
  return false if @adjust_points.nil?
  true
end