Class: FtcApiV3Client::ApiV3FFAchievementsDetail
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FtcApiV3Client::ApiV3FFAchievementsDetail
- Defined in:
- lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#auto_delivered ⇒ Object
Returns the value of attribute auto_delivered.
-
#auto_freight1 ⇒ Object
Returns the value of attribute auto_freight1.
-
#auto_freight2 ⇒ Object
Returns the value of attribute auto_freight2.
-
#auto_freight3 ⇒ Object
Returns the value of attribute auto_freight3.
-
#auto_robot1 ⇒ Object
Returns the value of attribute auto_robot1.
-
#auto_robot2 ⇒ Object
Returns the value of attribute auto_robot2.
-
#auto_storage_freight ⇒ Object
Returns the value of attribute auto_storage_freight.
-
#balanced ⇒ Object
Returns the value of attribute balanced.
-
#capped ⇒ Object
Returns the value of attribute capped.
-
#dc_freight1 ⇒ Object
Returns the value of attribute dc_freight1.
-
#dc_freight2 ⇒ Object
Returns the value of attribute dc_freight2.
-
#dc_freight3 ⇒ Object
Returns the value of attribute dc_freight3.
-
#dc_storage_freight ⇒ Object
Returns the value of attribute dc_storage_freight.
-
#eg_delivered ⇒ Object
Returns the value of attribute eg_delivered.
-
#eg_robot1 ⇒ Object
Returns the value of attribute eg_robot1.
-
#eg_robot2 ⇒ Object
Returns the value of attribute eg_robot2.
-
#init_tse1 ⇒ Object
Indicates if team 1 used a team shipping element.
-
#init_tse2 ⇒ Object
Indicates if team 2 used a team shipping element.
-
#major_penalties ⇒ Object
Returns the value of attribute major_penalties.
-
#minor_penalties ⇒ Object
Returns the value of attribute minor_penalties.
-
#preload1 ⇒ Object
Returns the value of attribute preload1.
-
#preload2 ⇒ Object
Returns the value of attribute preload2.
-
#shared_freight ⇒ Object
Returns the value of attribute shared_freight.
-
#shared_tipped ⇒ Object
Indicates if the shared shipping hub was tipped towards this alliance.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApiV3FFAchievementsDetail
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ApiV3FFAchievementsDetail
Initializes the object
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 173 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FtcApiV3Client::ApiV3FFAchievementsDetail` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FtcApiV3Client::ApiV3FFAchievementsDetail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'auto_delivered') self.auto_delivered = attributes[:'auto_delivered'] else self.auto_delivered = nil end if attributes.key?(:'auto_robot1') self.auto_robot1 = attributes[:'auto_robot1'] else self.auto_robot1 = nil end if attributes.key?(:'auto_robot2') self.auto_robot2 = attributes[:'auto_robot2'] else self.auto_robot2 = nil end if attributes.key?(:'preload1') self.preload1 = attributes[:'preload1'] else self.preload1 = nil end if attributes.key?(:'preload2') self.preload2 = attributes[:'preload2'] else self.preload2 = nil end if attributes.key?(:'auto_storage_freight') self.auto_storage_freight = attributes[:'auto_storage_freight'] else self.auto_storage_freight = nil end if attributes.key?(:'auto_freight1') self.auto_freight1 = attributes[:'auto_freight1'] else self.auto_freight1 = nil end if attributes.key?(:'auto_freight2') self.auto_freight2 = attributes[:'auto_freight2'] else self.auto_freight2 = nil end if attributes.key?(:'auto_freight3') self.auto_freight3 = attributes[:'auto_freight3'] else self.auto_freight3 = nil end if attributes.key?(:'dc_storage_freight') self.dc_storage_freight = attributes[:'dc_storage_freight'] else self.dc_storage_freight = nil end if attributes.key?(:'dc_freight1') self.dc_freight1 = attributes[:'dc_freight1'] else self.dc_freight1 = nil end if attributes.key?(:'dc_freight2') self.dc_freight2 = attributes[:'dc_freight2'] else self.dc_freight2 = nil end if attributes.key?(:'dc_freight3') self.dc_freight3 = attributes[:'dc_freight3'] else self.dc_freight3 = nil end if attributes.key?(:'shared_freight') self.shared_freight = attributes[:'shared_freight'] else self.shared_freight = nil end if attributes.key?(:'eg_delivered') self.eg_delivered = attributes[:'eg_delivered'] else self.eg_delivered = nil end if attributes.key?(:'balanced') self.balanced = attributes[:'balanced'] else self.balanced = nil end if attributes.key?(:'eg_robot1') self.eg_robot1 = attributes[:'eg_robot1'] else self.eg_robot1 = nil end if attributes.key?(:'eg_robot2') self.eg_robot2 = attributes[:'eg_robot2'] else self.eg_robot2 = nil end if attributes.key?(:'capped') self.capped = attributes[:'capped'] else self.capped = nil end if attributes.key?(:'minor_penalties') self.minor_penalties = attributes[:'minor_penalties'] else self.minor_penalties = nil end if attributes.key?(:'major_penalties') self.major_penalties = attributes[:'major_penalties'] else self.major_penalties = nil end if attributes.key?(:'init_tse1') self.init_tse1 = attributes[:'init_tse1'] else self.init_tse1 = nil end if attributes.key?(:'init_tse2') self.init_tse2 = attributes[:'init_tse2'] else self.init_tse2 = nil end if attributes.key?(:'shared_tipped') self.shared_tipped = attributes[:'shared_tipped'] else self.shared_tipped = nil end end |
Instance Attribute Details
#auto_delivered ⇒ Object
Returns the value of attribute auto_delivered.
18 19 20 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 18 def auto_delivered @auto_delivered end |
#auto_freight1 ⇒ Object
Returns the value of attribute auto_freight1.
30 31 32 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 30 def auto_freight1 @auto_freight1 end |
#auto_freight2 ⇒ Object
Returns the value of attribute auto_freight2.
32 33 34 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 32 def auto_freight2 @auto_freight2 end |
#auto_freight3 ⇒ Object
Returns the value of attribute auto_freight3.
34 35 36 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 34 def auto_freight3 @auto_freight3 end |
#auto_robot1 ⇒ Object
Returns the value of attribute auto_robot1.
20 21 22 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 20 def auto_robot1 @auto_robot1 end |
#auto_robot2 ⇒ Object
Returns the value of attribute auto_robot2.
22 23 24 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 22 def auto_robot2 @auto_robot2 end |
#auto_storage_freight ⇒ Object
Returns the value of attribute auto_storage_freight.
28 29 30 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 28 def auto_storage_freight @auto_storage_freight end |
#balanced ⇒ Object
Returns the value of attribute balanced.
48 49 50 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 48 def balanced @balanced end |
#capped ⇒ Object
Returns the value of attribute capped.
54 55 56 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 54 def capped @capped end |
#dc_freight1 ⇒ Object
Returns the value of attribute dc_freight1.
38 39 40 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 38 def dc_freight1 @dc_freight1 end |
#dc_freight2 ⇒ Object
Returns the value of attribute dc_freight2.
40 41 42 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 40 def dc_freight2 @dc_freight2 end |
#dc_freight3 ⇒ Object
Returns the value of attribute dc_freight3.
42 43 44 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 42 def dc_freight3 @dc_freight3 end |
#dc_storage_freight ⇒ Object
Returns the value of attribute dc_storage_freight.
36 37 38 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 36 def dc_storage_freight @dc_storage_freight end |
#eg_delivered ⇒ Object
Returns the value of attribute eg_delivered.
46 47 48 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 46 def eg_delivered @eg_delivered end |
#eg_robot1 ⇒ Object
Returns the value of attribute eg_robot1.
50 51 52 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 50 def eg_robot1 @eg_robot1 end |
#eg_robot2 ⇒ Object
Returns the value of attribute eg_robot2.
52 53 54 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 52 def eg_robot2 @eg_robot2 end |
#init_tse1 ⇒ Object
Indicates if team 1 used a team shipping element
61 62 63 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 61 def init_tse1 @init_tse1 end |
#init_tse2 ⇒ Object
Indicates if team 2 used a team shipping element
64 65 66 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 64 def init_tse2 @init_tse2 end |
#major_penalties ⇒ Object
Returns the value of attribute major_penalties.
58 59 60 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 58 def major_penalties @major_penalties end |
#minor_penalties ⇒ Object
Returns the value of attribute minor_penalties.
56 57 58 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 56 def minor_penalties @minor_penalties end |
#preload1 ⇒ Object
Returns the value of attribute preload1.
24 25 26 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 24 def preload1 @preload1 end |
#preload2 ⇒ Object
Returns the value of attribute preload2.
26 27 28 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 26 def preload2 @preload2 end |
#shared_freight ⇒ Object
Returns the value of attribute shared_freight.
44 45 46 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 44 def shared_freight @shared_freight end |
#shared_tipped ⇒ Object
Indicates if the shared shipping hub was tipped towards this alliance
67 68 69 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 67 def shared_tipped @shared_tipped end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
122 123 124 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 122 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
127 128 129 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 127 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 92 def self.attribute_map { :'auto_delivered' => :'autoDelivered', :'auto_robot1' => :'autoRobot1', :'auto_robot2' => :'autoRobot2', :'preload1' => :'preload1', :'preload2' => :'preload2', :'auto_storage_freight' => :'autoStorageFreight', :'auto_freight1' => :'autoFreight1', :'auto_freight2' => :'autoFreight2', :'auto_freight3' => :'autoFreight3', :'dc_storage_freight' => :'dcStorageFreight', :'dc_freight1' => :'dcFreight1', :'dc_freight2' => :'dcFreight2', :'dc_freight3' => :'dcFreight3', :'shared_freight' => :'sharedFreight', :'eg_delivered' => :'egDelivered', :'balanced' => :'balanced', :'eg_robot1' => :'egRobot1', :'eg_robot2' => :'egRobot2', :'capped' => :'capped', :'minor_penalties' => :'minorPenalties', :'major_penalties' => :'majorPenalties', :'init_tse1' => :'initTSE1', :'init_tse2' => :'initTSE2', :'shared_tipped' => :'sharedTipped' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 693 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
162 163 164 165 166 167 168 169 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 162 def self.openapi_nullable Set.new([ :'auto_robot1', :'auto_robot2', :'eg_robot1', :'eg_robot2', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 132 def self.openapi_types { :'auto_delivered' => :'Boolean', :'auto_robot1' => :'ApiV3FFAutoLocation', :'auto_robot2' => :'ApiV3FFAutoLocation', :'preload1' => :'Boolean', :'preload2' => :'Boolean', :'auto_storage_freight' => :'Integer', :'auto_freight1' => :'Integer', :'auto_freight2' => :'Integer', :'auto_freight3' => :'Integer', :'dc_storage_freight' => :'Integer', :'dc_freight1' => :'Integer', :'dc_freight2' => :'Integer', :'dc_freight3' => :'Integer', :'shared_freight' => :'Integer', :'eg_delivered' => :'Integer', :'balanced' => :'Boolean', :'eg_robot1' => :'ApiV3FFEndLocation', :'eg_robot2' => :'ApiV3FFEndLocation', :'capped' => :'Integer', :'minor_penalties' => :'Integer', :'major_penalties' => :'Integer', :'init_tse1' => :'Boolean', :'init_tse2' => :'Boolean', :'shared_tipped' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 649 def ==(o) return true if self.equal?(o) self.class == o.class && auto_delivered == o.auto_delivered && auto_robot1 == o.auto_robot1 && auto_robot2 == o.auto_robot2 && preload1 == o.preload1 && preload2 == o.preload2 && auto_storage_freight == o.auto_storage_freight && auto_freight1 == o.auto_freight1 && auto_freight2 == o.auto_freight2 && auto_freight3 == o.auto_freight3 && dc_storage_freight == o.dc_storage_freight && dc_freight1 == o.dc_freight1 && dc_freight2 == o.dc_freight2 && dc_freight3 == o.dc_freight3 && shared_freight == o.shared_freight && eg_delivered == o.eg_delivered && balanced == o.balanced && eg_robot1 == o.eg_robot1 && eg_robot2 == o.eg_robot2 && capped == o.capped && minor_penalties == o.minor_penalties && major_penalties == o.major_penalties && init_tse1 == o.init_tse1 && init_tse2 == o.init_tse2 && shared_tipped == o.shared_tipped end |
#eql?(o) ⇒ Boolean
680 681 682 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 680 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
686 687 688 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 686 def hash [auto_delivered, auto_robot1, auto_robot2, preload1, preload2, auto_storage_freight, auto_freight1, auto_freight2, auto_freight3, dc_storage_freight, dc_freight1, dc_freight2, dc_freight3, shared_freight, eg_delivered, balanced, eg_robot1, eg_robot2, capped, minor_penalties, major_penalties, init_tse1, init_tse2, shared_tipped].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 334 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @auto_delivered.nil? invalid_properties.push('invalid value for "auto_delivered", auto_delivered cannot be nil.') end if @preload1.nil? invalid_properties.push('invalid value for "preload1", preload1 cannot be nil.') end if @preload2.nil? invalid_properties.push('invalid value for "preload2", preload2 cannot be nil.') end if @auto_storage_freight.nil? invalid_properties.push('invalid value for "auto_storage_freight", auto_storage_freight cannot be nil.') end if @auto_freight1.nil? invalid_properties.push('invalid value for "auto_freight1", auto_freight1 cannot be nil.') end if @auto_freight2.nil? invalid_properties.push('invalid value for "auto_freight2", auto_freight2 cannot be nil.') end if @auto_freight3.nil? invalid_properties.push('invalid value for "auto_freight3", auto_freight3 cannot be nil.') end if @dc_storage_freight.nil? invalid_properties.push('invalid value for "dc_storage_freight", dc_storage_freight cannot be nil.') end if @dc_freight1.nil? invalid_properties.push('invalid value for "dc_freight1", dc_freight1 cannot be nil.') end if @dc_freight2.nil? invalid_properties.push('invalid value for "dc_freight2", dc_freight2 cannot be nil.') end if @dc_freight3.nil? invalid_properties.push('invalid value for "dc_freight3", dc_freight3 cannot be nil.') end if @shared_freight.nil? invalid_properties.push('invalid value for "shared_freight", shared_freight cannot be nil.') end if @eg_delivered.nil? invalid_properties.push('invalid value for "eg_delivered", eg_delivered cannot be nil.') end if @balanced.nil? invalid_properties.push('invalid value for "balanced", balanced cannot be nil.') end if @capped.nil? invalid_properties.push('invalid value for "capped", capped cannot be nil.') end if @minor_penalties.nil? invalid_properties.push('invalid value for "minor_penalties", minor_penalties cannot be nil.') end if @major_penalties.nil? invalid_properties.push('invalid value for "major_penalties", major_penalties cannot be nil.') end if @init_tse1.nil? invalid_properties.push('invalid value for "init_tse1", init_tse1 cannot be nil.') end if @init_tse2.nil? invalid_properties.push('invalid value for "init_tse2", init_tse2 cannot be nil.') end if @shared_tipped.nil? invalid_properties.push('invalid value for "shared_tipped", shared_tipped cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
715 716 717 718 719 720 721 722 723 724 725 726 727 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 715 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 |
# File 'lib/ftc_api_v3_client/models/api_v3_ff_achievements_detail.rb', line 422 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @auto_delivered.nil? return false if @preload1.nil? return false if @preload2.nil? return false if @auto_storage_freight.nil? return false if @auto_freight1.nil? return false if @auto_freight2.nil? return false if @auto_freight3.nil? return false if @dc_storage_freight.nil? return false if @dc_freight1.nil? return false if @dc_freight2.nil? return false if @dc_freight3.nil? return false if @shared_freight.nil? return false if @eg_delivered.nil? return false if @balanced.nil? return false if @capped.nil? return false if @minor_penalties.nil? return false if @major_penalties.nil? return false if @init_tse1.nil? return false if @init_tse2.nil? return false if @shared_tipped.nil? true end |