Class: FtcApiV3Client::ApiV3LeagueDetails
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FtcApiV3Client::ApiV3LeagueDetails
- Defined in:
- lib/ftc_api_v3_client/models/api_v3_league_details.rb
Instance Attribute Summary collapse
-
#children ⇒ Object
Returns the value of attribute children.
-
#code ⇒ Object
Returns the value of attribute code.
-
#location ⇒ Object
Returns the value of attribute location.
-
#name ⇒ Object
Returns the value of attribute name.
-
#parent_code ⇒ Object
Returns the value of attribute parent_code.
-
#remote ⇒ Object
Returns the value of attribute remote.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApiV3LeagueDetails
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ApiV3LeagueDetails
Initializes the object
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/ftc_api_v3_client/models/api_v3_league_details.rb', line 76 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FtcApiV3Client::ApiV3LeagueDetails` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FtcApiV3Client::ApiV3LeagueDetails`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'code') self.code = attributes[:'code'] else self.code = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'remote') self.remote = attributes[:'remote'] end if attributes.key?(:'location') self.location = attributes[:'location'] end if attributes.key?(:'parent_code') self.parent_code = attributes[:'parent_code'] end if attributes.key?(:'children') if (value = attributes[:'children']).is_a?(Array) self.children = value end else self.children = nil end end |
Instance Attribute Details
#children ⇒ Object
Returns the value of attribute children.
28 29 30 |
# File 'lib/ftc_api_v3_client/models/api_v3_league_details.rb', line 28 def children @children end |
#code ⇒ Object
Returns the value of attribute code.
18 19 20 |
# File 'lib/ftc_api_v3_client/models/api_v3_league_details.rb', line 18 def code @code end |
#location ⇒ Object
Returns the value of attribute location.
24 25 26 |
# File 'lib/ftc_api_v3_client/models/api_v3_league_details.rb', line 24 def location @location end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/ftc_api_v3_client/models/api_v3_league_details.rb', line 20 def name @name end |
#parent_code ⇒ Object
Returns the value of attribute parent_code.
26 27 28 |
# File 'lib/ftc_api_v3_client/models/api_v3_league_details.rb', line 26 def parent_code @parent_code end |
#remote ⇒ Object
Returns the value of attribute remote.
22 23 24 |
# File 'lib/ftc_api_v3_client/models/api_v3_league_details.rb', line 22 def remote @remote end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
43 44 45 |
# File 'lib/ftc_api_v3_client/models/api_v3_league_details.rb', line 43 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
48 49 50 |
# File 'lib/ftc_api_v3_client/models/api_v3_league_details.rb', line 48 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 |
# File 'lib/ftc_api_v3_client/models/api_v3_league_details.rb', line 31 def self.attribute_map { :'code' => :'code', :'name' => :'name', :'remote' => :'remote', :'location' => :'location', :'parent_code' => :'parentCode', :'children' => :'children' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/ftc_api_v3_client/models/api_v3_league_details.rb', line 181 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
65 66 67 68 69 70 71 72 |
# File 'lib/ftc_api_v3_client/models/api_v3_league_details.rb', line 65 def self.openapi_nullable Set.new([ :'code', :'name', :'location', :'parent_code', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 |
# File 'lib/ftc_api_v3_client/models/api_v3_league_details.rb', line 53 def self.openapi_types { :'code' => :'String', :'name' => :'String', :'remote' => :'Boolean', :'location' => :'String', :'parent_code' => :'String', :'children' => :'Array<ApiV3League>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
155 156 157 158 159 160 161 162 163 164 |
# File 'lib/ftc_api_v3_client/models/api_v3_league_details.rb', line 155 def ==(o) return true if self.equal?(o) self.class == o.class && code == o.code && name == o.name && remote == o.remote && location == o.location && parent_code == o.parent_code && children == o.children end |
#eql?(o) ⇒ Boolean
168 169 170 |
# File 'lib/ftc_api_v3_client/models/api_v3_league_details.rb', line 168 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
174 175 176 |
# File 'lib/ftc_api_v3_client/models/api_v3_league_details.rb', line 174 def hash [code, name, remote, location, parent_code, children].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
125 126 127 128 129 130 131 132 133 |
# File 'lib/ftc_api_v3_client/models/api_v3_league_details.rb', line 125 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @children.nil? invalid_properties.push('invalid value for "children", children cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/ftc_api_v3_client/models/api_v3_league_details.rb', line 203 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
137 138 139 140 141 |
# File 'lib/ftc_api_v3_client/models/api_v3_league_details.rb', line 137 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @children.nil? true end |