Class: FtcApiV3Client::ApiV3PlayoffSeriesDescription

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ftc_api_v3_client/models/api_v3_playoff_series_description.rb

Overview

A series in a single-elimination structure

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ApiV3PlayoffSeriesDescription

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/ftc_api_v3_client/models/api_v3_playoff_series_description.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FtcApiV3Client::ApiV3PlayoffSeriesDescription` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FtcApiV3Client::ApiV3PlayoffSeriesDescription`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'series_id')
    self.series_id = attributes[:'series_id']
  else
    self.series_id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'short_name')
    self.short_name = attributes[:'short_name']
  else
    self.short_name = nil
  end

  if attributes.key?(:'matches_to_win')
    self.matches_to_win = attributes[:'matches_to_win']
  else
    self.matches_to_win = nil
  end

  if attributes.key?(:'round')
    self.round = attributes[:'round']
  else
    self.round = nil
  end

  if attributes.key?(:'red')
    self.red = attributes[:'red']
  else
    self.red = nil
  end

  if attributes.key?(:'blue')
    self.blue = attributes[:'blue']
  else
    self.blue = nil
  end

  if attributes.key?(:'finals')
    self.finals = attributes[:'finals']
  else
    self.finals = nil
  end
end

Instance Attribute Details

#blueObject

Returns the value of attribute blue.



31
32
33
# File 'lib/ftc_api_v3_client/models/api_v3_playoff_series_description.rb', line 31

def blue
  @blue
end

#finalsObject

Returns the value of attribute finals.



33
34
35
# File 'lib/ftc_api_v3_client/models/api_v3_playoff_series_description.rb', line 33

def finals
  @finals
end

#matches_to_winObject

Returns the value of attribute matches_to_win.



25
26
27
# File 'lib/ftc_api_v3_client/models/api_v3_playoff_series_description.rb', line 25

def matches_to_win
  @matches_to_win
end

#nameObject

Returns the value of attribute name.



21
22
23
# File 'lib/ftc_api_v3_client/models/api_v3_playoff_series_description.rb', line 21

def name
  @name
end

#redObject

Returns the value of attribute red.



29
30
31
# File 'lib/ftc_api_v3_client/models/api_v3_playoff_series_description.rb', line 29

def red
  @red
end

#roundObject

Returns the value of attribute round.



27
28
29
# File 'lib/ftc_api_v3_client/models/api_v3_playoff_series_description.rb', line 27

def round
  @round
end

#series_idObject

Returns the value of attribute series_id.



19
20
21
# File 'lib/ftc_api_v3_client/models/api_v3_playoff_series_description.rb', line 19

def series_id
  @series_id
end

#short_nameObject

Returns the value of attribute short_name.



23
24
25
# File 'lib/ftc_api_v3_client/models/api_v3_playoff_series_description.rb', line 23

def short_name
  @short_name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/ftc_api_v3_client/models/api_v3_playoff_series_description.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/ftc_api_v3_client/models/api_v3_playoff_series_description.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
46
47
# File 'lib/ftc_api_v3_client/models/api_v3_playoff_series_description.rb', line 36

def self.attribute_map
  {
    :'series_id' => :'seriesId',
    :'name' => :'name',
    :'short_name' => :'shortName',
    :'matches_to_win' => :'matchesToWin',
    :'round' => :'round',
    :'red' => :'red',
    :'blue' => :'blue',
    :'finals' => :'finals'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/ftc_api_v3_client/models/api_v3_playoff_series_description.rb', line 281

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



74
75
76
77
78
79
# File 'lib/ftc_api_v3_client/models/api_v3_playoff_series_description.rb', line 74

def self.openapi_nullable
  Set.new([
    :'name',
    :'short_name',
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/ftc_api_v3_client/models/api_v3_playoff_series_description.rb', line 60

def self.openapi_types
  {
    :'series_id' => :'Integer',
    :'name' => :'String',
    :'short_name' => :'String',
    :'matches_to_win' => :'Integer',
    :'round' => :'Integer',
    :'red' => :'ApiV3AllianceDescription',
    :'blue' => :'ApiV3AllianceDescription',
    :'finals' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/ftc_api_v3_client/models/api_v3_playoff_series_description.rb', line 253

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      series_id == o.series_id &&
      name == o.name &&
      short_name == o.short_name &&
      matches_to_win == o.matches_to_win &&
      round == o.round &&
      red == o.red &&
      blue == o.blue &&
      finals == o.finals
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


268
269
270
# File 'lib/ftc_api_v3_client/models/api_v3_playoff_series_description.rb', line 268

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



274
275
276
# File 'lib/ftc_api_v3_client/models/api_v3_playoff_series_description.rb', line 274

def hash
  [series_id, name, short_name, matches_to_win, round, red, blue, finals].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/ftc_api_v3_client/models/api_v3_playoff_series_description.rb', line 148

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @series_id.nil?
    invalid_properties.push('invalid value for "series_id", series_id cannot be nil.')
  end

  if @matches_to_win.nil?
    invalid_properties.push('invalid value for "matches_to_win", matches_to_win cannot be nil.')
  end

  if @round.nil?
    invalid_properties.push('invalid value for "round", round cannot be nil.')
  end

  if @red.nil?
    invalid_properties.push('invalid value for "red", red cannot be nil.')
  end

  if @blue.nil?
    invalid_properties.push('invalid value for "blue", blue cannot be nil.')
  end

  if @finals.nil?
    invalid_properties.push('invalid value for "finals", finals cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/ftc_api_v3_client/models/api_v3_playoff_series_description.rb', line 303

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



180
181
182
183
184
185
186
187
188
189
# File 'lib/ftc_api_v3_client/models/api_v3_playoff_series_description.rb', line 180

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @series_id.nil?
  return false if @matches_to_win.nil?
  return false if @round.nil?
  return false if @red.nil?
  return false if @blue.nil?
  return false if @finals.nil?
  true
end