Class: FtcApiV3Client::ApiV3Ranking

Inherits:
ApiModelBase show all
Defined in:
lib/ftc_api_v3_client/models/api_v3_ranking.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ApiV3Ranking

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/ftc_api_v3_client/models/api_v3_ranking.rb', line 80

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FtcApiV3Client::ApiV3Ranking` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FtcApiV3Client::ApiV3Ranking`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'rank')
    self.rank = attributes[:'rank']
  else
    self.rank = nil
  end

  if attributes.key?(:'team')
    self.team = attributes[:'team']
  else
    self.team = nil
  end

  if attributes.key?(:'sort_orders')
    if (value = attributes[:'sort_orders']).is_a?(Array)
      self.sort_orders = value
    end
  else
    self.sort_orders = nil
  end

  if attributes.key?(:'wins')
    self.wins = attributes[:'wins']
  else
    self.wins = nil
  end

  if attributes.key?(:'losses')
    self.losses = attributes[:'losses']
  else
    self.losses = nil
  end

  if attributes.key?(:'ties')
    self.ties = attributes[:'ties']
  else
    self.ties = nil
  end

  if attributes.key?(:'matches_counted')
    self.matches_counted = attributes[:'matches_counted']
  else
    self.matches_counted = nil
  end

  if attributes.key?(:'matches_played')
    self.matches_played = attributes[:'matches_played']
  else
    self.matches_played = nil
  end
end

Instance Attribute Details

#lossesObject

Returns the value of attribute losses.



26
27
28
# File 'lib/ftc_api_v3_client/models/api_v3_ranking.rb', line 26

def losses
  @losses
end

#matches_countedObject

Returns the value of attribute matches_counted.



30
31
32
# File 'lib/ftc_api_v3_client/models/api_v3_ranking.rb', line 30

def matches_counted
  @matches_counted
end

#matches_playedObject

Returns the value of attribute matches_played.



32
33
34
# File 'lib/ftc_api_v3_client/models/api_v3_ranking.rb', line 32

def matches_played
  @matches_played
end

#rankObject

Returns the value of attribute rank.



18
19
20
# File 'lib/ftc_api_v3_client/models/api_v3_ranking.rb', line 18

def rank
  @rank
end

#sort_ordersObject

Returns the value of attribute sort_orders.



22
23
24
# File 'lib/ftc_api_v3_client/models/api_v3_ranking.rb', line 22

def sort_orders
  @sort_orders
end

#teamObject

Returns the value of attribute team.



20
21
22
# File 'lib/ftc_api_v3_client/models/api_v3_ranking.rb', line 20

def team
  @team
end

#tiesObject

Returns the value of attribute ties.



28
29
30
# File 'lib/ftc_api_v3_client/models/api_v3_ranking.rb', line 28

def ties
  @ties
end

#winsObject

Returns the value of attribute wins.



24
25
26
# File 'lib/ftc_api_v3_client/models/api_v3_ranking.rb', line 24

def wins
  @wins
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/ftc_api_v3_client/models/api_v3_ranking.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/ftc_api_v3_client/models/api_v3_ranking.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
45
46
# File 'lib/ftc_api_v3_client/models/api_v3_ranking.rb', line 35

def self.attribute_map
  {
    :'rank' => :'rank',
    :'team' => :'team',
    :'sort_orders' => :'sortOrders',
    :'wins' => :'wins',
    :'losses' => :'losses',
    :'ties' => :'ties',
    :'matches_counted' => :'matchesCounted',
    :'matches_played' => :'matchesPlayed'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/ftc_api_v3_client/models/api_v3_ranking.rb', line 310

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



73
74
75
76
# File 'lib/ftc_api_v3_client/models/api_v3_ranking.rb', line 73

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/ftc_api_v3_client/models/api_v3_ranking.rb', line 59

def self.openapi_types
  {
    :'rank' => :'Integer',
    :'team' => :'ApiV3SimpleTeam',
    :'sort_orders' => :'Array<String>',
    :'wins' => :'Integer',
    :'losses' => :'Integer',
    :'ties' => :'Integer',
    :'matches_counted' => :'Integer',
    :'matches_played' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/ftc_api_v3_client/models/api_v3_ranking.rb', line 282

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      rank == o.rank &&
      team == o.team &&
      sort_orders == o.sort_orders &&
      wins == o.wins &&
      losses == o.losses &&
      ties == o.ties &&
      matches_counted == o.matches_counted &&
      matches_played == o.matches_played
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


297
298
299
# File 'lib/ftc_api_v3_client/models/api_v3_ranking.rb', line 297

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



303
304
305
# File 'lib/ftc_api_v3_client/models/api_v3_ranking.rb', line 303

def hash
  [rank, team, sort_orders, wins, losses, ties, matches_counted, matches_played].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/ftc_api_v3_client/models/api_v3_ranking.rb', line 147

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @rank.nil?
    invalid_properties.push('invalid value for "rank", rank cannot be nil.')
  end

  if @team.nil?
    invalid_properties.push('invalid value for "team", team cannot be nil.')
  end

  if @sort_orders.nil?
    invalid_properties.push('invalid value for "sort_orders", sort_orders cannot be nil.')
  end

  if @wins.nil?
    invalid_properties.push('invalid value for "wins", wins cannot be nil.')
  end

  if @losses.nil?
    invalid_properties.push('invalid value for "losses", losses cannot be nil.')
  end

  if @ties.nil?
    invalid_properties.push('invalid value for "ties", ties cannot be nil.')
  end

  if @matches_counted.nil?
    invalid_properties.push('invalid value for "matches_counted", matches_counted cannot be nil.')
  end

  if @matches_played.nil?
    invalid_properties.push('invalid value for "matches_played", matches_played cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/ftc_api_v3_client/models/api_v3_ranking.rb', line 332

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/ftc_api_v3_client/models/api_v3_ranking.rb', line 187

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @rank.nil?
  return false if @team.nil?
  return false if @sort_orders.nil?
  return false if @wins.nil?
  return false if @losses.nil?
  return false if @ties.nil?
  return false if @matches_counted.nil?
  return false if @matches_played.nil?
  true
end