Class: FtcApiV3Client::ApiV3RoundRobinAllianceDescription
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FtcApiV3Client::ApiV3RoundRobinAllianceDescription
- Defined in:
- lib/ftc_api_v3_client/models/api_v3_round_robin_alliance_description.rb
Overview
An alliance that is determined by final ranking in round-robin play
Instance Attribute Summary collapse
-
#rank ⇒ Object
Returns the value of attribute rank.
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApiV3RoundRobinAllianceDescription
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ApiV3RoundRobinAllianceDescription
Initializes the object
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/ftc_api_v3_client/models/api_v3_round_robin_alliance_description.rb', line 58 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FtcApiV3Client::ApiV3RoundRobinAllianceDescription` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FtcApiV3Client::ApiV3RoundRobinAllianceDescription`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'rank') self.rank = attributes[:'rank'] else self.rank = nil end end |
Instance Attribute Details
#rank ⇒ Object
Returns the value of attribute rank.
21 22 23 |
# File 'lib/ftc_api_v3_client/models/api_v3_round_robin_alliance_description.rb', line 21 def rank @rank end |
#type ⇒ Object
Returns the value of attribute type.
19 20 21 |
# File 'lib/ftc_api_v3_client/models/api_v3_round_robin_alliance_description.rb', line 19 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
32 33 34 |
# File 'lib/ftc_api_v3_client/models/api_v3_round_robin_alliance_description.rb', line 32 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
37 38 39 |
# File 'lib/ftc_api_v3_client/models/api_v3_round_robin_alliance_description.rb', line 37 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
24 25 26 27 28 29 |
# File 'lib/ftc_api_v3_client/models/api_v3_round_robin_alliance_description.rb', line 24 def self.attribute_map { :'type' => :'type', :'rank' => :'rank' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/ftc_api_v3_client/models/api_v3_round_robin_alliance_description.rb', line 139 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
50 51 52 53 54 |
# File 'lib/ftc_api_v3_client/models/api_v3_round_robin_alliance_description.rb', line 50 def self.openapi_nullable Set.new([ :'type', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
42 43 44 45 46 47 |
# File 'lib/ftc_api_v3_client/models/api_v3_round_robin_alliance_description.rb', line 42 def self.openapi_types { :'type' => :'String', :'rank' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
117 118 119 120 121 122 |
# File 'lib/ftc_api_v3_client/models/api_v3_round_robin_alliance_description.rb', line 117 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && rank == o.rank end |
#eql?(o) ⇒ Boolean
126 127 128 |
# File 'lib/ftc_api_v3_client/models/api_v3_round_robin_alliance_description.rb', line 126 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
132 133 134 |
# File 'lib/ftc_api_v3_client/models/api_v3_round_robin_alliance_description.rb', line 132 def hash [type, rank].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
87 88 89 90 91 92 93 94 95 |
# File 'lib/ftc_api_v3_client/models/api_v3_round_robin_alliance_description.rb', line 87 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @rank.nil? invalid_properties.push('invalid value for "rank", rank cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/ftc_api_v3_client/models/api_v3_round_robin_alliance_description.rb', line 161 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
99 100 101 102 103 |
# File 'lib/ftc_api_v3_client/models/api_v3_round_robin_alliance_description.rb', line 99 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @rank.nil? true end |