Class: FtcApiV3Client::ApiV3SeriesAllianceDescription

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ftc_api_v3_client/models/api_v3_series_alliance_description.rb

Overview

An alliance that is determined by the outcome of a previous series (e.g. the winner of SF-1)

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ApiV3SeriesAllianceDescription

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/ftc_api_v3_client/models/api_v3_series_alliance_description.rb', line 85

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FtcApiV3Client::ApiV3SeriesAllianceDescription` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FtcApiV3Client::ApiV3SeriesAllianceDescription`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'series_id')
    self.series_id = attributes[:'series_id']
  else
    self.series_id = nil
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = nil
  end
end

Instance Attribute Details

#series_idObject

Returns the value of attribute series_id.



21
22
23
# File 'lib/ftc_api_v3_client/models/api_v3_series_alliance_description.rb', line 21

def series_id
  @series_id
end

#stateObject

Returns the value of attribute state.



23
24
25
# File 'lib/ftc_api_v3_client/models/api_v3_series_alliance_description.rb', line 23

def state
  @state
end

#typeObject

Returns the value of attribute type.



19
20
21
# File 'lib/ftc_api_v3_client/models/api_v3_series_alliance_description.rb', line 19

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/ftc_api_v3_client/models/api_v3_series_alliance_description.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/ftc_api_v3_client/models/api_v3_series_alliance_description.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
# File 'lib/ftc_api_v3_client/models/api_v3_series_alliance_description.rb', line 48

def self.attribute_map
  {
    :'type' => :'type',
    :'series_id' => :'seriesId',
    :'state' => :'state'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/ftc_api_v3_client/models/api_v3_series_alliance_description.rb', line 173

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
80
81
# File 'lib/ftc_api_v3_client/models/api_v3_series_alliance_description.rb', line 76

def self.openapi_nullable
  Set.new([
    :'type',
    :'state'
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
# File 'lib/ftc_api_v3_client/models/api_v3_series_alliance_description.rb', line 67

def self.openapi_types
  {
    :'type' => :'String',
    :'series_id' => :'Integer',
    :'state' => :'ApiV3SeriesAllianceState'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



150
151
152
153
154
155
156
# File 'lib/ftc_api_v3_client/models/api_v3_series_alliance_description.rb', line 150

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      series_id == o.series_id &&
      state == o.state
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


160
161
162
# File 'lib/ftc_api_v3_client/models/api_v3_series_alliance_description.rb', line 160

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



166
167
168
# File 'lib/ftc_api_v3_client/models/api_v3_series_alliance_description.rb', line 166

def hash
  [type, series_id, state].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



120
121
122
123
124
125
126
127
128
# File 'lib/ftc_api_v3_client/models/api_v3_series_alliance_description.rb', line 120

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @series_id.nil?
    invalid_properties.push('invalid value for "series_id", series_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/ftc_api_v3_client/models/api_v3_series_alliance_description.rb', line 195

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



132
133
134
135
136
# File 'lib/ftc_api_v3_client/models/api_v3_series_alliance_description.rb', line 132

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @series_id.nil?
  true
end