Class: FtcApiV3Client::ApiV3SimpleEvent

Inherits:
ApiModelBase show all
Defined in:
lib/ftc_api_v3_client/models/api_v3_simple_event.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ApiV3SimpleEvent

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 150

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FtcApiV3Client::ApiV3SimpleEvent` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FtcApiV3Client::ApiV3SimpleEvent`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'code')
    self.code = attributes[:'code']
  else
    self.code = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'format')
    self.format = attributes[:'format']
  else
    self.format = nil
  end

  if attributes.key?(:'start_date')
    self.start_date = attributes[:'start_date']
  else
    self.start_date = nil
  end

  if attributes.key?(:'end_date')
    self.end_date = attributes[:'end_date']
  else
    self.end_date = nil
  end

  if attributes.key?(:'region_code')
    self.region_code = attributes[:'region_code']
  else
    self.region_code = nil
  end

  if attributes.key?(:'venue')
    self.venue = attributes[:'venue']
  end

  if attributes.key?(:'street_address')
    self.street_address = attributes[:'street_address']
  end

  if attributes.key?(:'street_address2')
    self.street_address2 = attributes[:'street_address2']
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'website')
    self.website = attributes[:'website']
  end

  if attributes.key?(:'published')
    self.published = attributes[:'published']
  else
    self.published = nil
  end

  if attributes.key?(:'timezone')
    self.timezone = attributes[:'timezone']
  else
    self.timezone = nil
  end
end

Instance Attribute Details

#cityObject

Returns the value of attribute city.



38
39
40
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 38

def city
  @city
end

#codeObject

Returns the value of attribute code.



18
19
20
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 18

def code
  @code
end

#countryObject

Returns the value of attribute country.



42
43
44
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 42

def country
  @country
end

#end_dateObject

Returns the value of attribute end_date.



28
29
30
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 28

def end_date
  @end_date
end

#formatObject

Returns the value of attribute format.



24
25
26
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 24

def format
  @format
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 20

def name
  @name
end

#publishedObject

Returns the value of attribute published.



46
47
48
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 46

def published
  @published
end

#region_codeObject

Returns the value of attribute region_code.



30
31
32
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 30

def region_code
  @region_code
end

#start_dateObject

Returns the value of attribute start_date.



26
27
28
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 26

def start_date
  @start_date
end

#stateObject

Returns the value of attribute state.



40
41
42
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 40

def state
  @state
end

#street_addressObject

Returns the value of attribute street_address.



34
35
36
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 34

def street_address
  @street_address
end

#street_address2Object

Returns the value of attribute street_address2.



36
37
38
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 36

def street_address2
  @street_address2
end

#timezoneObject

All timestamps related to the event are exposed in the API as local date/times in the event timezone



49
50
51
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 49

def timezone
  @timezone
end

#typeObject

Returns the value of attribute type.



22
23
24
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 22

def type
  @type
end

#venueObject

Returns the value of attribute venue.



32
33
34
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 32

def venue
  @venue
end

#websiteObject

Returns the value of attribute website.



44
45
46
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 44

def website
  @website
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



96
97
98
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 96

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



101
102
103
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 101

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 74

def self.attribute_map
  {
    :'code' => :'code',
    :'name' => :'name',
    :'type' => :'type',
    :'format' => :'format',
    :'start_date' => :'startDate',
    :'end_date' => :'endDate',
    :'region_code' => :'regionCode',
    :'venue' => :'venue',
    :'street_address' => :'streetAddress',
    :'street_address2' => :'streetAddress2',
    :'city' => :'city',
    :'state' => :'state',
    :'country' => :'country',
    :'website' => :'website',
    :'published' => :'published',
    :'timezone' => :'timezone'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 315

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 128

def self.openapi_nullable
  Set.new([
    :'code',
    :'name',
    :'type',
    :'format',
    :'start_date',
    :'end_date',
    :'region_code',
    :'venue',
    :'street_address',
    :'street_address2',
    :'city',
    :'state',
    :'country',
    :'website',
    :'timezone'
  ])
end

.openapi_typesObject

Attribute type mapping.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 106

def self.openapi_types
  {
    :'code' => :'String',
    :'name' => :'String',
    :'type' => :'ApiV3EventType',
    :'format' => :'ApiV3EventFormat',
    :'start_date' => :'Date',
    :'end_date' => :'Date',
    :'region_code' => :'String',
    :'venue' => :'String',
    :'street_address' => :'String',
    :'street_address2' => :'String',
    :'city' => :'String',
    :'state' => :'String',
    :'country' => :'String',
    :'website' => :'String',
    :'published' => :'Boolean',
    :'timezone' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 279

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      code == o.code &&
      name == o.name &&
      type == o.type &&
      format == o.format &&
      start_date == o.start_date &&
      end_date == o.end_date &&
      region_code == o.region_code &&
      venue == o.venue &&
      street_address == o.street_address &&
      street_address2 == o.street_address2 &&
      city == o.city &&
      state == o.state &&
      country == o.country &&
      website == o.website &&
      published == o.published &&
      timezone == o.timezone
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


302
303
304
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 302

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



308
309
310
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 308

def hash
  [code, name, type, format, start_date, end_date, region_code, venue, street_address, street_address2, city, state, country, website, published, timezone].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



249
250
251
252
253
254
255
256
257
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 249

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @published.nil?
    invalid_properties.push('invalid value for "published", published cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 337

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



261
262
263
264
265
# File 'lib/ftc_api_v3_client/models/api_v3_simple_event.rb', line 261

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @published.nil?
  true
end