Class: FtcApiV3Client::ApiV3SimpleTeam
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FtcApiV3Client::ApiV3SimpleTeam
- Defined in:
- lib/ftc_api_v3_client/models/api_v3_simple_team.rb
Instance Attribute Summary collapse
-
#display_number ⇒ Object
Use this for presentation purposes; it may include a shorter representation of the official team number for some teams in some seasons.
-
#name ⇒ Object
Returns the value of attribute name.
-
#number ⇒ Object
Returns the value of attribute number.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApiV3SimpleTeam
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ApiV3SimpleTeam
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/ftc_api_v3_client/models/api_v3_simple_team.rb', line 64 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FtcApiV3Client::ApiV3SimpleTeam` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FtcApiV3Client::ApiV3SimpleTeam`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'number') self.number = attributes[:'number'] else self.number = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'display_number') self.display_number = attributes[:'display_number'] else self.display_number = nil end end |
Instance Attribute Details
#display_number ⇒ Object
Use this for presentation purposes; it may include a shorter representation of the official team number for some teams in some seasons.
23 24 25 |
# File 'lib/ftc_api_v3_client/models/api_v3_simple_team.rb', line 23 def display_number @display_number end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/ftc_api_v3_client/models/api_v3_simple_team.rb', line 20 def name @name end |
#number ⇒ Object
Returns the value of attribute number.
18 19 20 |
# File 'lib/ftc_api_v3_client/models/api_v3_simple_team.rb', line 18 def number @number end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
35 36 37 |
# File 'lib/ftc_api_v3_client/models/api_v3_simple_team.rb', line 35 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
40 41 42 |
# File 'lib/ftc_api_v3_client/models/api_v3_simple_team.rb', line 40 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 32 |
# File 'lib/ftc_api_v3_client/models/api_v3_simple_team.rb', line 26 def self.attribute_map { :'number' => :'number', :'name' => :'name', :'display_number' => :'displayNumber' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/ftc_api_v3_client/models/api_v3_simple_team.rb', line 137 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
54 55 56 57 58 59 60 |
# File 'lib/ftc_api_v3_client/models/api_v3_simple_team.rb', line 54 def self.openapi_nullable Set.new([ :'number', :'name', :'display_number' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
45 46 47 48 49 50 51 |
# File 'lib/ftc_api_v3_client/models/api_v3_simple_team.rb', line 45 def self.openapi_types { :'number' => :'String', :'name' => :'String', :'display_number' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
114 115 116 117 118 119 120 |
# File 'lib/ftc_api_v3_client/models/api_v3_simple_team.rb', line 114 def ==(o) return true if self.equal?(o) self.class == o.class && number == o.number && name == o.name && display_number == o.display_number end |
#eql?(o) ⇒ Boolean
124 125 126 |
# File 'lib/ftc_api_v3_client/models/api_v3_simple_team.rb', line 124 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
130 131 132 |
# File 'lib/ftc_api_v3_client/models/api_v3_simple_team.rb', line 130 def hash [number, name, display_number].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
99 100 101 102 103 |
# File 'lib/ftc_api_v3_client/models/api_v3_simple_team.rb', line 99 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/ftc_api_v3_client/models/api_v3_simple_team.rb', line 159 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
107 108 109 110 |
# File 'lib/ftc_api_v3_client/models/api_v3_simple_team.rb', line 107 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |