Class: FtcApiV3Client::ApiV3SingleAwardRecipient

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ftc_api_v3_client/models/api_v3_single_award_recipient.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ApiV3SingleAwardRecipient

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/ftc_api_v3_client/models/api_v3_single_award_recipient.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FtcApiV3Client::ApiV3SingleAwardRecipient` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FtcApiV3Client::ApiV3SingleAwardRecipient`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'ordered')
    self.ordered = attributes[:'ordered']
  else
    self.ordered = nil
  end

  if attributes.key?(:'individual')
    self.individual = attributes[:'individual']
  else
    self.individual = nil
  end

  if attributes.key?(:'sub_name')
    self.sub_name = attributes[:'sub_name']
  end

  if attributes.key?(:'place')
    self.place = attributes[:'place']
  end
end

Instance Attribute Details

#descriptionObject

Returns the value of attribute description.



22
23
24
# File 'lib/ftc_api_v3_client/models/api_v3_single_award_recipient.rb', line 22

def description
  @description
end

#individualObject

Returns the value of attribute individual.



26
27
28
# File 'lib/ftc_api_v3_client/models/api_v3_single_award_recipient.rb', line 26

def individual
  @individual
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/ftc_api_v3_client/models/api_v3_single_award_recipient.rb', line 20

def name
  @name
end

#orderedObject

Returns the value of attribute ordered.



24
25
26
# File 'lib/ftc_api_v3_client/models/api_v3_single_award_recipient.rb', line 24

def ordered
  @ordered
end

#placeObject

Only populated for awards that are ordered



32
33
34
# File 'lib/ftc_api_v3_client/models/api_v3_single_award_recipient.rb', line 32

def place
  @place
end

#sub_nameObject

For division awards (e.g. winner/finalist), the division name. For conference awards from POWERPLAY championship, the conference name. Null otherwise.



29
30
31
# File 'lib/ftc_api_v3_client/models/api_v3_single_award_recipient.rb', line 29

def sub_name
  @sub_name
end

#typeObject

Returns the value of attribute type.



18
19
20
# File 'lib/ftc_api_v3_client/models/api_v3_single_award_recipient.rb', line 18

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



70
71
72
# File 'lib/ftc_api_v3_client/models/api_v3_single_award_recipient.rb', line 70

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/ftc_api_v3_client/models/api_v3_single_award_recipient.rb', line 75

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
# File 'lib/ftc_api_v3_client/models/api_v3_single_award_recipient.rb', line 57

def self.attribute_map
  {
    :'type' => :'type',
    :'name' => :'name',
    :'description' => :'description',
    :'ordered' => :'ordered',
    :'individual' => :'individual',
    :'sub_name' => :'subName',
    :'place' => :'place'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/ftc_api_v3_client/models/api_v3_single_award_recipient.rb', line 229

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
97
98
99
100
# File 'lib/ftc_api_v3_client/models/api_v3_single_award_recipient.rb', line 93

def self.openapi_nullable
  Set.new([
    :'type',
    :'name',
    :'description',
    :'sub_name',
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
90
# File 'lib/ftc_api_v3_client/models/api_v3_single_award_recipient.rb', line 80

def self.openapi_types
  {
    :'type' => :'ApiV3AwardType',
    :'name' => :'String',
    :'description' => :'String',
    :'ordered' => :'Boolean',
    :'individual' => :'Boolean',
    :'sub_name' => :'String',
    :'place' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



202
203
204
205
206
207
208
209
210
211
212
# File 'lib/ftc_api_v3_client/models/api_v3_single_award_recipient.rb', line 202

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      name == o.name &&
      description == o.description &&
      ordered == o.ordered &&
      individual == o.individual &&
      sub_name == o.sub_name &&
      place == o.place
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


216
217
218
# File 'lib/ftc_api_v3_client/models/api_v3_single_award_recipient.rb', line 216

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



222
223
224
# File 'lib/ftc_api_v3_client/models/api_v3_single_award_recipient.rb', line 222

def hash
  [type, name, description, ordered, individual, sub_name, place].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/ftc_api_v3_client/models/api_v3_single_award_recipient.rb', line 157

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @ordered.nil?
    invalid_properties.push('invalid value for "ordered", ordered cannot be nil.')
  end

  if @individual.nil?
    invalid_properties.push('invalid value for "individual", individual cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/ftc_api_v3_client/models/api_v3_single_award_recipient.rb', line 251

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



173
174
175
176
177
178
# File 'lib/ftc_api_v3_client/models/api_v3_single_award_recipient.rb', line 173

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @ordered.nil?
  return false if @individual.nil?
  true
end