Class: FtcApiV3Client::ApiV3Team
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FtcApiV3Client::ApiV3Team
- Defined in:
- lib/ftc_api_v3_client/models/api_v3_team.rb
Instance Attribute Summary collapse
-
#affiliations ⇒ Object
Returns the value of attribute affiliations.
-
#city ⇒ Object
Returns the value of attribute city.
-
#coordinates ⇒ Object
Coordinates are for the team's city.
-
#country ⇒ Object
Returns the value of attribute country.
-
#display_number ⇒ Object
Use this for presentation purposes; it may include a shorter representation of the official team number for some teams in some seasons.
-
#home_region_code ⇒ Object
Returns the value of attribute home_region_code.
-
#name ⇒ Object
Returns the value of attribute name.
-
#number ⇒ Object
Returns the value of attribute number.
-
#rookie_cmp_year ⇒ Object
Returns the value of attribute rookie_cmp_year.
-
#state_prov ⇒ Object
Returns the value of attribute state_prov.
-
#website ⇒ Object
Returns the value of attribute website.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApiV3Team
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ApiV3Team
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/ftc_api_v3_client/models/api_v3_team.rb', line 103 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FtcApiV3Client::ApiV3Team` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FtcApiV3Client::ApiV3Team`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'number') self.number = attributes[:'number'] else self.number = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'affiliations') self.affiliations = attributes[:'affiliations'] else self.affiliations = nil end if attributes.key?(:'city') self.city = attributes[:'city'] end if attributes.key?(:'state_prov') self.state_prov = attributes[:'state_prov'] end if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'rookie_cmp_year') self.rookie_cmp_year = attributes[:'rookie_cmp_year'] else self.rookie_cmp_year = nil end if attributes.key?(:'website') self.website = attributes[:'website'] end if attributes.key?(:'home_region_code') self.home_region_code = attributes[:'home_region_code'] end if attributes.key?(:'display_number') self.display_number = attributes[:'display_number'] else self.display_number = nil end if attributes.key?(:'coordinates') self.coordinates = attributes[:'coordinates'] end end |
Instance Attribute Details
#affiliations ⇒ Object
Returns the value of attribute affiliations.
22 23 24 |
# File 'lib/ftc_api_v3_client/models/api_v3_team.rb', line 22 def affiliations @affiliations end |
#city ⇒ Object
Returns the value of attribute city.
24 25 26 |
# File 'lib/ftc_api_v3_client/models/api_v3_team.rb', line 24 def city @city end |
#coordinates ⇒ Object
Coordinates are for the team's city
40 41 42 |
# File 'lib/ftc_api_v3_client/models/api_v3_team.rb', line 40 def coordinates @coordinates end |
#country ⇒ Object
Returns the value of attribute country.
28 29 30 |
# File 'lib/ftc_api_v3_client/models/api_v3_team.rb', line 28 def country @country end |
#display_number ⇒ Object
Use this for presentation purposes; it may include a shorter representation of the official team number for some teams in some seasons.
37 38 39 |
# File 'lib/ftc_api_v3_client/models/api_v3_team.rb', line 37 def display_number @display_number end |
#home_region_code ⇒ Object
Returns the value of attribute home_region_code.
34 35 36 |
# File 'lib/ftc_api_v3_client/models/api_v3_team.rb', line 34 def home_region_code @home_region_code end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/ftc_api_v3_client/models/api_v3_team.rb', line 20 def name @name end |
#number ⇒ Object
Returns the value of attribute number.
18 19 20 |
# File 'lib/ftc_api_v3_client/models/api_v3_team.rb', line 18 def number @number end |
#rookie_cmp_year ⇒ Object
Returns the value of attribute rookie_cmp_year.
30 31 32 |
# File 'lib/ftc_api_v3_client/models/api_v3_team.rb', line 30 def rookie_cmp_year @rookie_cmp_year end |
#state_prov ⇒ Object
Returns the value of attribute state_prov.
26 27 28 |
# File 'lib/ftc_api_v3_client/models/api_v3_team.rb', line 26 def state_prov @state_prov end |
#website ⇒ Object
Returns the value of attribute website.
32 33 34 |
# File 'lib/ftc_api_v3_client/models/api_v3_team.rb', line 32 def website @website end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
60 61 62 |
# File 'lib/ftc_api_v3_client/models/api_v3_team.rb', line 60 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
65 66 67 |
# File 'lib/ftc_api_v3_client/models/api_v3_team.rb', line 65 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/ftc_api_v3_client/models/api_v3_team.rb', line 43 def self.attribute_map { :'number' => :'number', :'name' => :'name', :'affiliations' => :'affiliations', :'city' => :'city', :'state_prov' => :'stateProv', :'country' => :'country', :'rookie_cmp_year' => :'rookieCmpYear', :'website' => :'website', :'home_region_code' => :'homeRegionCode', :'display_number' => :'displayNumber', :'coordinates' => :'coordinates' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/ftc_api_v3_client/models/api_v3_team.rb', line 235 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/ftc_api_v3_client/models/api_v3_team.rb', line 87 def self.openapi_nullable Set.new([ :'number', :'name', :'affiliations', :'city', :'state_prov', :'country', :'website', :'home_region_code', :'display_number', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/ftc_api_v3_client/models/api_v3_team.rb', line 70 def self.openapi_types { :'number' => :'String', :'name' => :'String', :'affiliations' => :'String', :'city' => :'String', :'state_prov' => :'String', :'country' => :'String', :'rookie_cmp_year' => :'Integer', :'website' => :'String', :'home_region_code' => :'String', :'display_number' => :'String', :'coordinates' => :'ApiV3Coordinates' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/ftc_api_v3_client/models/api_v3_team.rb', line 204 def ==(o) return true if self.equal?(o) self.class == o.class && number == o.number && name == o.name && affiliations == o.affiliations && city == o.city && state_prov == o.state_prov && country == o.country && rookie_cmp_year == o.rookie_cmp_year && website == o.website && home_region_code == o.home_region_code && display_number == o.display_number && coordinates == o.coordinates end |
#eql?(o) ⇒ Boolean
222 223 224 |
# File 'lib/ftc_api_v3_client/models/api_v3_team.rb', line 222 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
228 229 230 |
# File 'lib/ftc_api_v3_client/models/api_v3_team.rb', line 228 def hash [number, name, affiliations, city, state_prov, country, rookie_cmp_year, website, home_region_code, display_number, coordinates].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
174 175 176 177 178 179 180 181 182 |
# File 'lib/ftc_api_v3_client/models/api_v3_team.rb', line 174 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @rookie_cmp_year.nil? invalid_properties.push('invalid value for "rookie_cmp_year", rookie_cmp_year cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/ftc_api_v3_client/models/api_v3_team.rb', line 257 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
186 187 188 189 190 |
# File 'lib/ftc_api_v3_client/models/api_v3_team.rb', line 186 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @rookie_cmp_year.nil? true end |