Class: FtcApiV3Client::ApiV3UgRemotePointsDetail

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ApiV3UgRemotePointsDetail

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb', line 105

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FtcApiV3Client::ApiV3UgRemotePointsDetail` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FtcApiV3Client::ApiV3UgRemotePointsDetail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'auto_navigation_points')
    self.auto_navigation_points = attributes[:'auto_navigation_points']
  else
    self.auto_navigation_points = nil
  end

  if attributes.key?(:'auto_wobble_points')
    self.auto_wobble_points = attributes[:'auto_wobble_points']
  else
    self.auto_wobble_points = nil
  end

  if attributes.key?(:'auto_tower_points')
    self.auto_tower_points = attributes[:'auto_tower_points']
  else
    self.auto_tower_points = nil
  end

  if attributes.key?(:'auto_power_shot_points')
    self.auto_power_shot_points = attributes[:'auto_power_shot_points']
  else
    self.auto_power_shot_points = nil
  end

  if attributes.key?(:'dc_tower_points')
    self.dc_tower_points = attributes[:'dc_tower_points']
  else
    self.dc_tower_points = nil
  end

  if attributes.key?(:'end_wobble_points')
    self.end_wobble_points = attributes[:'end_wobble_points']
  else
    self.end_wobble_points = nil
  end

  if attributes.key?(:'end_wobble_ring_points')
    self.end_wobble_ring_points = attributes[:'end_wobble_ring_points']
  else
    self.end_wobble_ring_points = nil
  end

  if attributes.key?(:'end_power_shot_points')
    self.end_power_shot_points = attributes[:'end_power_shot_points']
  else
    self.end_power_shot_points = nil
  end

  if attributes.key?(:'auto_points')
    self.auto_points = attributes[:'auto_points']
  else
    self.auto_points = nil
  end

  if attributes.key?(:'dc_points')
    self.dc_points = attributes[:'dc_points']
  else
    self.dc_points = nil
  end

  if attributes.key?(:'endgame_points')
    self.endgame_points = attributes[:'endgame_points']
  else
    self.endgame_points = nil
  end

  if attributes.key?(:'penalty_points_committed')
    self.penalty_points_committed = attributes[:'penalty_points_committed']
  else
    self.penalty_points_committed = nil
  end

  if attributes.key?(:'pre_penalty_total')
    self.pre_penalty_total = attributes[:'pre_penalty_total']
  else
    self.pre_penalty_total = nil
  end

  if attributes.key?(:'adjust_points')
    self.adjust_points = attributes[:'adjust_points']
  else
    self.adjust_points = nil
  end
end

Instance Attribute Details

#adjust_pointsObject

Used to indicate the winner in double-red-card playoff matches



45
46
47
# File 'lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb', line 45

def adjust_points
  @adjust_points
end

#auto_navigation_pointsObject

Returns the value of attribute auto_navigation_points.



18
19
20
# File 'lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb', line 18

def auto_navigation_points
  @auto_navigation_points
end

#auto_pointsObject

Returns the value of attribute auto_points.



34
35
36
# File 'lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb', line 34

def auto_points
  @auto_points
end

#auto_power_shot_pointsObject

Returns the value of attribute auto_power_shot_points.



24
25
26
# File 'lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb', line 24

def auto_power_shot_points
  @auto_power_shot_points
end

#auto_tower_pointsObject

Returns the value of attribute auto_tower_points.



22
23
24
# File 'lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb', line 22

def auto_tower_points
  @auto_tower_points
end

#auto_wobble_pointsObject

Returns the value of attribute auto_wobble_points.



20
21
22
# File 'lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb', line 20

def auto_wobble_points
  @auto_wobble_points
end

#dc_pointsObject

Returns the value of attribute dc_points.



36
37
38
# File 'lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb', line 36

def dc_points
  @dc_points
end

#dc_tower_pointsObject

Returns the value of attribute dc_tower_points.



26
27
28
# File 'lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb', line 26

def dc_tower_points
  @dc_tower_points
end

#end_power_shot_pointsObject

Returns the value of attribute end_power_shot_points.



32
33
34
# File 'lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb', line 32

def end_power_shot_points
  @end_power_shot_points
end

#end_wobble_pointsObject

Returns the value of attribute end_wobble_points.



28
29
30
# File 'lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb', line 28

def end_wobble_points
  @end_wobble_points
end

#end_wobble_ring_pointsObject

Returns the value of attribute end_wobble_ring_points.



30
31
32
# File 'lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb', line 30

def end_wobble_ring_points
  @end_wobble_ring_points
end

#endgame_pointsObject

Returns the value of attribute endgame_points.



38
39
40
# File 'lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb', line 38

def endgame_points
  @endgame_points
end

#penalty_points_committedObject

Returns the value of attribute penalty_points_committed.



40
41
42
# File 'lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb', line 40

def penalty_points_committed
  @penalty_points_committed
end

#pre_penalty_totalObject

Returns the value of attribute pre_penalty_total.



42
43
44
# File 'lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb', line 42

def pre_penalty_total
  @pre_penalty_total
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



68
69
70
# File 'lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb', line 68

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb', line 73

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb', line 48

def self.attribute_map
  {
    :'auto_navigation_points' => :'autoNavigationPoints',
    :'auto_wobble_points' => :'autoWobblePoints',
    :'auto_tower_points' => :'autoTowerPoints',
    :'auto_power_shot_points' => :'autoPowerShotPoints',
    :'dc_tower_points' => :'dcTowerPoints',
    :'end_wobble_points' => :'endWobblePoints',
    :'end_wobble_ring_points' => :'endWobbleRingPoints',
    :'end_power_shot_points' => :'endPowerShotPoints',
    :'auto_points' => :'autoPoints',
    :'dc_points' => :'dcPoints',
    :'endgame_points' => :'endgamePoints',
    :'penalty_points_committed' => :'penaltyPointsCommitted',
    :'pre_penalty_total' => :'prePenaltyTotal',
    :'adjust_points' => :'adjustPoints'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
# File 'lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb', line 465

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



98
99
100
101
# File 'lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb', line 98

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb', line 78

def self.openapi_types
  {
    :'auto_navigation_points' => :'Integer',
    :'auto_wobble_points' => :'Integer',
    :'auto_tower_points' => :'Integer',
    :'auto_power_shot_points' => :'Integer',
    :'dc_tower_points' => :'Integer',
    :'end_wobble_points' => :'Integer',
    :'end_wobble_ring_points' => :'Integer',
    :'end_power_shot_points' => :'Integer',
    :'auto_points' => :'Integer',
    :'dc_points' => :'Integer',
    :'endgame_points' => :'Integer',
    :'penalty_points_committed' => :'Integer',
    :'pre_penalty_total' => :'Integer',
    :'adjust_points' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
# File 'lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb', line 431

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      auto_navigation_points == o.auto_navigation_points &&
      auto_wobble_points == o.auto_wobble_points &&
      auto_tower_points == o.auto_tower_points &&
      auto_power_shot_points == o.auto_power_shot_points &&
      dc_tower_points == o.dc_tower_points &&
      end_wobble_points == o.end_wobble_points &&
      end_wobble_ring_points == o.end_wobble_ring_points &&
      end_power_shot_points == o.end_power_shot_points &&
      auto_points == o.auto_points &&
      dc_points == o.dc_points &&
      endgame_points == o.endgame_points &&
      penalty_points_committed == o.penalty_points_committed &&
      pre_penalty_total == o.pre_penalty_total &&
      adjust_points == o.adjust_points
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


452
453
454
# File 'lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb', line 452

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



458
459
460
# File 'lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb', line 458

def hash
  [auto_navigation_points, auto_wobble_points, auto_tower_points, auto_power_shot_points, dc_tower_points, end_wobble_points, end_wobble_ring_points, end_power_shot_points, auto_points, dc_points, endgame_points, penalty_points_committed, pre_penalty_total, adjust_points].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb', line 206

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @auto_navigation_points.nil?
    invalid_properties.push('invalid value for "auto_navigation_points", auto_navigation_points cannot be nil.')
  end

  if @auto_wobble_points.nil?
    invalid_properties.push('invalid value for "auto_wobble_points", auto_wobble_points cannot be nil.')
  end

  if @auto_tower_points.nil?
    invalid_properties.push('invalid value for "auto_tower_points", auto_tower_points cannot be nil.')
  end

  if @auto_power_shot_points.nil?
    invalid_properties.push('invalid value for "auto_power_shot_points", auto_power_shot_points cannot be nil.')
  end

  if @dc_tower_points.nil?
    invalid_properties.push('invalid value for "dc_tower_points", dc_tower_points cannot be nil.')
  end

  if @end_wobble_points.nil?
    invalid_properties.push('invalid value for "end_wobble_points", end_wobble_points cannot be nil.')
  end

  if @end_wobble_ring_points.nil?
    invalid_properties.push('invalid value for "end_wobble_ring_points", end_wobble_ring_points cannot be nil.')
  end

  if @end_power_shot_points.nil?
    invalid_properties.push('invalid value for "end_power_shot_points", end_power_shot_points cannot be nil.')
  end

  if @auto_points.nil?
    invalid_properties.push('invalid value for "auto_points", auto_points cannot be nil.')
  end

  if @dc_points.nil?
    invalid_properties.push('invalid value for "dc_points", dc_points cannot be nil.')
  end

  if @endgame_points.nil?
    invalid_properties.push('invalid value for "endgame_points", endgame_points cannot be nil.')
  end

  if @penalty_points_committed.nil?
    invalid_properties.push('invalid value for "penalty_points_committed", penalty_points_committed cannot be nil.')
  end

  if @pre_penalty_total.nil?
    invalid_properties.push('invalid value for "pre_penalty_total", pre_penalty_total cannot be nil.')
  end

  if @adjust_points.nil?
    invalid_properties.push('invalid value for "adjust_points", adjust_points cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



487
488
489
490
491
492
493
494
495
496
497
498
499
# File 'lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb', line 487

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/ftc_api_v3_client/models/api_v3_ug_remote_points_detail.rb', line 270

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @auto_navigation_points.nil?
  return false if @auto_wobble_points.nil?
  return false if @auto_tower_points.nil?
  return false if @auto_power_shot_points.nil?
  return false if @dc_tower_points.nil?
  return false if @end_wobble_points.nil?
  return false if @end_wobble_ring_points.nil?
  return false if @end_power_shot_points.nil?
  return false if @auto_points.nil?
  return false if @dc_points.nil?
  return false if @endgame_points.nil?
  return false if @penalty_points_committed.nil?
  return false if @pre_penalty_total.nil?
  return false if @adjust_points.nil?
  true
end