Class: FtcApiV3Client::SeasonsApi
- Inherits:
-
Object
- Object
- FtcApiV3Client::SeasonsApi
- Defined in:
- lib/ftc_api_v3_client/api/seasons_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_season(cmp_year, opts = {}) ⇒ ApiV3Season
Get single FTC season Lists basic information about the given FTC season.
-
#get_season_with_http_info(cmp_year, opts = {}) ⇒ Array<(ApiV3Season, Integer, Hash)>
Get single FTC season Lists basic information about the given FTC season.
-
#initialize(api_client = ApiClient.default) ⇒ SeasonsApi
constructor
A new instance of SeasonsApi.
-
#list_seasons(opts = {}) ⇒ ApiV3Seasons
List all FTC seasons Lists basic information about all FTC seasons with data available through this API.
-
#list_seasons_with_http_info(opts = {}) ⇒ Array<(ApiV3Seasons, Integer, Hash)>
List all FTC seasons Lists basic information about all FTC seasons with data available through this API.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ SeasonsApi
Returns a new instance of SeasonsApi.
19 20 21 |
# File 'lib/ftc_api_v3_client/api/seasons_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/ftc_api_v3_client/api/seasons_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_season(cmp_year, opts = {}) ⇒ ApiV3Season
Get single FTC season Lists basic information about the given FTC season
27 28 29 30 |
# File 'lib/ftc_api_v3_client/api/seasons_api.rb', line 27 def get_season(cmp_year, opts = {}) data, _status_code, _headers = get_season_with_http_info(cmp_year, opts) data end |
#get_season_with_http_info(cmp_year, opts = {}) ⇒ Array<(ApiV3Season, Integer, Hash)>
Get single FTC season Lists basic information about the given FTC season
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/ftc_api_v3_client/api/seasons_api.rb', line 37 def get_season_with_http_info(cmp_year, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SeasonsApi.get_season ...' end # resource path local_var_path = '/api/v3/seasons/{cmpYear}'.sub('{' + 'cmpYear' + '}', CGI.escape(cmp_year.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ApiV3Season' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"SeasonsApi.get_season", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SeasonsApi#get_season\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_seasons(opts = {}) ⇒ ApiV3Seasons
List all FTC seasons Lists basic information about all FTC seasons with data available through this API
85 86 87 88 |
# File 'lib/ftc_api_v3_client/api/seasons_api.rb', line 85 def list_seasons(opts = {}) data, _status_code, _headers = list_seasons_with_http_info(opts) data end |
#list_seasons_with_http_info(opts = {}) ⇒ Array<(ApiV3Seasons, Integer, Hash)>
List all FTC seasons Lists basic information about all FTC seasons with data available through this API
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/ftc_api_v3_client/api/seasons_api.rb', line 94 def list_seasons_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SeasonsApi.list_seasons ...' end # resource path local_var_path = '/api/v3/seasons' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ApiV3Seasons' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"SeasonsApi.list_seasons", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SeasonsApi#list_seasons\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |