Class: FtcApiV3Client::ApiV3DoubleEliminationSeriesDescription
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FtcApiV3Client::ApiV3DoubleEliminationSeriesDescription
- Defined in:
- lib/ftc_api_v3_client/models/api_v3_double_elimination_series_description.rb
Overview
A series in a double-elimination structure
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#blue ⇒ Object
Returns the value of attribute blue.
-
#bracket_half ⇒ Object
Returns the value of attribute bracket_half.
-
#finals ⇒ Object
Returns the value of attribute finals.
-
#matches_to_win ⇒ Object
Returns the value of attribute matches_to_win.
-
#name ⇒ Object
Returns the value of attribute name.
-
#optional ⇒ Object
This series is only played if necessary (e.g. if the alliance from the lower bracket wins the first finals match).
-
#red ⇒ Object
Returns the value of attribute red.
-
#round ⇒ Object
Returns the value of attribute round.
-
#series_id ⇒ Object
Returns the value of attribute series_id.
-
#short_name ⇒ Object
Returns the value of attribute short_name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApiV3DoubleEliminationSeriesDescription
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ApiV3DoubleEliminationSeriesDescription
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/ftc_api_v3_client/models/api_v3_double_elimination_series_description.rb', line 115 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FtcApiV3Client::ApiV3DoubleEliminationSeriesDescription` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FtcApiV3Client::ApiV3DoubleEliminationSeriesDescription`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'series_id') self.series_id = attributes[:'series_id'] else self.series_id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'short_name') self.short_name = attributes[:'short_name'] else self.short_name = nil end if attributes.key?(:'matches_to_win') self.matches_to_win = attributes[:'matches_to_win'] else self.matches_to_win = nil end if attributes.key?(:'round') self.round = attributes[:'round'] else self.round = nil end if attributes.key?(:'red') self.red = attributes[:'red'] else self.red = nil end if attributes.key?(:'blue') self.blue = attributes[:'blue'] else self.blue = nil end if attributes.key?(:'finals') self.finals = attributes[:'finals'] else self.finals = nil end if attributes.key?(:'bracket_half') self.bracket_half = attributes[:'bracket_half'] end if attributes.key?(:'optional') self.optional = attributes[:'optional'] else self.optional = nil end end |
Instance Attribute Details
#blue ⇒ Object
Returns the value of attribute blue.
31 32 33 |
# File 'lib/ftc_api_v3_client/models/api_v3_double_elimination_series_description.rb', line 31 def blue @blue end |
#bracket_half ⇒ Object
Returns the value of attribute bracket_half.
35 36 37 |
# File 'lib/ftc_api_v3_client/models/api_v3_double_elimination_series_description.rb', line 35 def bracket_half @bracket_half end |
#finals ⇒ Object
Returns the value of attribute finals.
33 34 35 |
# File 'lib/ftc_api_v3_client/models/api_v3_double_elimination_series_description.rb', line 33 def finals @finals end |
#matches_to_win ⇒ Object
Returns the value of attribute matches_to_win.
25 26 27 |
# File 'lib/ftc_api_v3_client/models/api_v3_double_elimination_series_description.rb', line 25 def matches_to_win @matches_to_win end |
#name ⇒ Object
Returns the value of attribute name.
21 22 23 |
# File 'lib/ftc_api_v3_client/models/api_v3_double_elimination_series_description.rb', line 21 def name @name end |
#optional ⇒ Object
This series is only played if necessary (e.g. if the alliance from the lower bracket wins the first finals match)
38 39 40 |
# File 'lib/ftc_api_v3_client/models/api_v3_double_elimination_series_description.rb', line 38 def optional @optional end |
#red ⇒ Object
Returns the value of attribute red.
29 30 31 |
# File 'lib/ftc_api_v3_client/models/api_v3_double_elimination_series_description.rb', line 29 def red @red end |
#round ⇒ Object
Returns the value of attribute round.
27 28 29 |
# File 'lib/ftc_api_v3_client/models/api_v3_double_elimination_series_description.rb', line 27 def round @round end |
#series_id ⇒ Object
Returns the value of attribute series_id.
19 20 21 |
# File 'lib/ftc_api_v3_client/models/api_v3_double_elimination_series_description.rb', line 19 def series_id @series_id end |
#short_name ⇒ Object
Returns the value of attribute short_name.
23 24 25 |
# File 'lib/ftc_api_v3_client/models/api_v3_double_elimination_series_description.rb', line 23 def short_name @short_name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
79 80 81 |
# File 'lib/ftc_api_v3_client/models/api_v3_double_elimination_series_description.rb', line 79 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
84 85 86 |
# File 'lib/ftc_api_v3_client/models/api_v3_double_elimination_series_description.rb', line 84 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/ftc_api_v3_client/models/api_v3_double_elimination_series_description.rb', line 63 def self.attribute_map { :'series_id' => :'seriesId', :'name' => :'name', :'short_name' => :'shortName', :'matches_to_win' => :'matchesToWin', :'round' => :'round', :'red' => :'red', :'blue' => :'blue', :'finals' => :'finals', :'bracket_half' => :'bracketHalf', :'optional' => :'optional' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/ftc_api_v3_client/models/api_v3_double_elimination_series_description.rb', line 340 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
105 106 107 108 109 110 111 |
# File 'lib/ftc_api_v3_client/models/api_v3_double_elimination_series_description.rb', line 105 def self.openapi_nullable Set.new([ :'name', :'short_name', :'bracket_half', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/ftc_api_v3_client/models/api_v3_double_elimination_series_description.rb', line 89 def self.openapi_types { :'series_id' => :'Integer', :'name' => :'String', :'short_name' => :'String', :'matches_to_win' => :'Integer', :'round' => :'Integer', :'red' => :'ApiV3AllianceDescription', :'blue' => :'ApiV3AllianceDescription', :'finals' => :'Boolean', :'bracket_half' => :'ApiV3DoubleElimsBracketHalf', :'optional' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
310 311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/ftc_api_v3_client/models/api_v3_double_elimination_series_description.rb', line 310 def ==(o) return true if self.equal?(o) self.class == o.class && series_id == o.series_id && name == o.name && short_name == o.short_name && matches_to_win == o.matches_to_win && round == o.round && red == o.red && blue == o.blue && finals == o.finals && bracket_half == o.bracket_half && optional == o.optional end |
#eql?(o) ⇒ Boolean
327 328 329 |
# File 'lib/ftc_api_v3_client/models/api_v3_double_elimination_series_description.rb', line 327 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
333 334 335 |
# File 'lib/ftc_api_v3_client/models/api_v3_double_elimination_series_description.rb', line 333 def hash [series_id, name, short_name, matches_to_win, round, red, blue, finals, bracket_half, optional].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/ftc_api_v3_client/models/api_v3_double_elimination_series_description.rb', line 190 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @series_id.nil? invalid_properties.push('invalid value for "series_id", series_id cannot be nil.') end if @matches_to_win.nil? invalid_properties.push('invalid value for "matches_to_win", matches_to_win cannot be nil.') end if @round.nil? invalid_properties.push('invalid value for "round", round cannot be nil.') end if @red.nil? invalid_properties.push('invalid value for "red", red cannot be nil.') end if @blue.nil? invalid_properties.push('invalid value for "blue", blue cannot be nil.') end if @finals.nil? invalid_properties.push('invalid value for "finals", finals cannot be nil.') end if @optional.nil? invalid_properties.push('invalid value for "optional", optional cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
362 363 364 365 366 367 368 369 370 371 372 373 374 |
# File 'lib/ftc_api_v3_client/models/api_v3_double_elimination_series_description.rb', line 362 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/ftc_api_v3_client/models/api_v3_double_elimination_series_description.rb', line 226 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @series_id.nil? return false if @matches_to_win.nil? return false if @round.nil? return false if @red.nil? return false if @blue.nil? return false if @finals.nil? return false if @optional.nil? true end |