Class: FtcApiV3Client::ApiV3PitMapElement
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FtcApiV3Client::ApiV3PitMapElement
- Defined in:
- lib/ftc_api_v3_client/models/api_v3_pit_map_element.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#address ⇒ Object
Returns the value of attribute address.
-
#address_group ⇒ Object
Returns the value of attribute address_group.
-
#color ⇒ Object
Returns the value of attribute color.
-
#height ⇒ Object
Returns the value of attribute height.
-
#index ⇒ Object
Returns the value of attribute index.
-
#label ⇒ Object
Returns the value of attribute label.
-
#label_orientation ⇒ Object
Returns the value of attribute label_orientation.
-
#team ⇒ Object
Returns the value of attribute team.
-
#type ⇒ Object
Returns the value of attribute type.
-
#width ⇒ Object
Returns the value of attribute width.
-
#x ⇒ Object
Returns the value of attribute x.
-
#y ⇒ Object
Returns the value of attribute y.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApiV3PitMapElement
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ApiV3PitMapElement
Initializes the object
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/ftc_api_v3_client/models/api_v3_pit_map_element.rb', line 124 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FtcApiV3Client::ApiV3PitMapElement` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FtcApiV3Client::ApiV3PitMapElement`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'x') self.x = attributes[:'x'] else self.x = nil end if attributes.key?(:'y') self.y = attributes[:'y'] else self.y = nil end if attributes.key?(:'width') self.width = attributes[:'width'] else self.width = nil end if attributes.key?(:'height') self.height = attributes[:'height'] else self.height = nil end if attributes.key?(:'label') self.label = attributes[:'label'] end if attributes.key?(:'label_orientation') self.label_orientation = attributes[:'label_orientation'] end if attributes.key?(:'index') self.index = attributes[:'index'] end if attributes.key?(:'team') self.team = attributes[:'team'] end if attributes.key?(:'address') self.address = attributes[:'address'] end if attributes.key?(:'address_group') self.address_group = attributes[:'address_group'] end if attributes.key?(:'color') self.color = attributes[:'color'] end end |
Instance Attribute Details
#address ⇒ Object
Returns the value of attribute address.
36 37 38 |
# File 'lib/ftc_api_v3_client/models/api_v3_pit_map_element.rb', line 36 def address @address end |
#address_group ⇒ Object
Returns the value of attribute address_group.
38 39 40 |
# File 'lib/ftc_api_v3_client/models/api_v3_pit_map_element.rb', line 38 def address_group @address_group end |
#color ⇒ Object
Returns the value of attribute color.
40 41 42 |
# File 'lib/ftc_api_v3_client/models/api_v3_pit_map_element.rb', line 40 def color @color end |
#height ⇒ Object
Returns the value of attribute height.
26 27 28 |
# File 'lib/ftc_api_v3_client/models/api_v3_pit_map_element.rb', line 26 def height @height end |
#index ⇒ Object
Returns the value of attribute index.
32 33 34 |
# File 'lib/ftc_api_v3_client/models/api_v3_pit_map_element.rb', line 32 def index @index end |
#label ⇒ Object
Returns the value of attribute label.
28 29 30 |
# File 'lib/ftc_api_v3_client/models/api_v3_pit_map_element.rb', line 28 def label @label end |
#label_orientation ⇒ Object
Returns the value of attribute label_orientation.
30 31 32 |
# File 'lib/ftc_api_v3_client/models/api_v3_pit_map_element.rb', line 30 def label_orientation @label_orientation end |
#team ⇒ Object
Returns the value of attribute team.
34 35 36 |
# File 'lib/ftc_api_v3_client/models/api_v3_pit_map_element.rb', line 34 def team @team end |
#type ⇒ Object
Returns the value of attribute type.
18 19 20 |
# File 'lib/ftc_api_v3_client/models/api_v3_pit_map_element.rb', line 18 def type @type end |
#width ⇒ Object
Returns the value of attribute width.
24 25 26 |
# File 'lib/ftc_api_v3_client/models/api_v3_pit_map_element.rb', line 24 def width @width end |
#x ⇒ Object
Returns the value of attribute x.
20 21 22 |
# File 'lib/ftc_api_v3_client/models/api_v3_pit_map_element.rb', line 20 def x @x end |
#y ⇒ Object
Returns the value of attribute y.
22 23 24 |
# File 'lib/ftc_api_v3_client/models/api_v3_pit_map_element.rb', line 22 def y @y end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
83 84 85 |
# File 'lib/ftc_api_v3_client/models/api_v3_pit_map_element.rb', line 83 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
88 89 90 |
# File 'lib/ftc_api_v3_client/models/api_v3_pit_map_element.rb', line 88 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/ftc_api_v3_client/models/api_v3_pit_map_element.rb', line 65 def self.attribute_map { :'type' => :'type', :'x' => :'x', :'y' => :'y', :'width' => :'width', :'height' => :'height', :'label' => :'label', :'label_orientation' => :'labelOrientation', :'index' => :'index', :'team' => :'team', :'address' => :'address', :'address_group' => :'addressGroup', :'color' => :'color' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/ftc_api_v3_client/models/api_v3_pit_map_element.rb', line 304 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
111 112 113 114 115 116 117 118 119 120 |
# File 'lib/ftc_api_v3_client/models/api_v3_pit_map_element.rb', line 111 def self.openapi_nullable Set.new([ :'type', :'label', :'label_orientation', :'address', :'address_group', :'color' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/ftc_api_v3_client/models/api_v3_pit_map_element.rb', line 93 def self.openapi_types { :'type' => :'ApiV3PitMapCellType', :'x' => :'Integer', :'y' => :'Integer', :'width' => :'Integer', :'height' => :'Integer', :'label' => :'String', :'label_orientation' => :'ApiV3PitMapLabelOrientation', :'index' => :'Integer', :'team' => :'ApiV3SimpleTeam', :'address' => :'String', :'address_group' => :'String', :'color' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/ftc_api_v3_client/models/api_v3_pit_map_element.rb', line 272 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && x == o.x && y == o.y && width == o.width && height == o.height && label == o.label && label_orientation == o.label_orientation && index == o.index && team == o.team && address == o.address && address_group == o.address_group && color == o.color end |
#eql?(o) ⇒ Boolean
291 292 293 |
# File 'lib/ftc_api_v3_client/models/api_v3_pit_map_element.rb', line 291 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
297 298 299 |
# File 'lib/ftc_api_v3_client/models/api_v3_pit_map_element.rb', line 297 def hash [type, x, y, width, height, label, label_orientation, index, team, address, address_group, color].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/ftc_api_v3_client/models/api_v3_pit_map_element.rb', line 197 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @x.nil? invalid_properties.push('invalid value for "x", x cannot be nil.') end if @y.nil? invalid_properties.push('invalid value for "y", y cannot be nil.') end if @width.nil? invalid_properties.push('invalid value for "width", width cannot be nil.') end if @height.nil? invalid_properties.push('invalid value for "height", height cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/ftc_api_v3_client/models/api_v3_pit_map_element.rb', line 326 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
221 222 223 224 225 226 227 228 |
# File 'lib/ftc_api_v3_client/models/api_v3_pit_map_element.rb', line 221 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @x.nil? return false if @y.nil? return false if @width.nil? return false if @height.nil? true end |