Class: FtcApiV3Client::ApiV3PowerPlayRemotePointsDetail
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FtcApiV3Client::ApiV3PowerPlayRemotePointsDetail
- Defined in:
- lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb
Instance Attribute Summary collapse
-
#auto_junction_cone_points ⇒ Object
Returns the value of attribute auto_junction_cone_points.
-
#auto_navigation_points ⇒ Object
Returns the value of attribute auto_navigation_points.
-
#auto_points ⇒ Object
Returns the value of attribute auto_points.
-
#auto_terminal_cone_points ⇒ Object
Returns the value of attribute auto_terminal_cone_points.
-
#circuit_points ⇒ Object
Returns the value of attribute circuit_points.
-
#dc_junction_cone_points ⇒ Object
Returns the value of attribute dc_junction_cone_points.
-
#dc_points ⇒ Object
Returns the value of attribute dc_points.
-
#dc_terminal_cone_points ⇒ Object
Returns the value of attribute dc_terminal_cone_points.
-
#eg_navigation_points ⇒ Object
Returns the value of attribute eg_navigation_points.
-
#endgame_points ⇒ Object
Returns the value of attribute endgame_points.
-
#ownership_points ⇒ Object
Returns the value of attribute ownership_points.
-
#penalty_points_committed ⇒ Object
Returns the value of attribute penalty_points_committed.
-
#pre_penalty_total ⇒ Object
Returns the value of attribute pre_penalty_total.
-
#signal_bonus_points ⇒ Object
Returns the value of attribute signal_bonus_points.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApiV3PowerPlayRemotePointsDetail
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ApiV3PowerPlayRemotePointsDetail
Initializes the object
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb', line 104 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FtcApiV3Client::ApiV3PowerPlayRemotePointsDetail` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FtcApiV3Client::ApiV3PowerPlayRemotePointsDetail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'auto_navigation_points') self. = attributes[:'auto_navigation_points'] else self. = nil end if attributes.key?(:'signal_bonus_points') self.signal_bonus_points = attributes[:'signal_bonus_points'] else self.signal_bonus_points = nil end if attributes.key?(:'auto_junction_cone_points') self.auto_junction_cone_points = attributes[:'auto_junction_cone_points'] else self.auto_junction_cone_points = nil end if attributes.key?(:'auto_terminal_cone_points') self.auto_terminal_cone_points = attributes[:'auto_terminal_cone_points'] else self.auto_terminal_cone_points = nil end if attributes.key?(:'dc_junction_cone_points') self.dc_junction_cone_points = attributes[:'dc_junction_cone_points'] else self.dc_junction_cone_points = nil end if attributes.key?(:'dc_terminal_cone_points') self.dc_terminal_cone_points = attributes[:'dc_terminal_cone_points'] else self.dc_terminal_cone_points = nil end if attributes.key?(:'ownership_points') self.ownership_points = attributes[:'ownership_points'] else self.ownership_points = nil end if attributes.key?(:'circuit_points') self.circuit_points = attributes[:'circuit_points'] else self.circuit_points = nil end if attributes.key?(:'eg_navigation_points') self. = attributes[:'eg_navigation_points'] else self. = nil end if attributes.key?(:'auto_points') self.auto_points = attributes[:'auto_points'] else self.auto_points = nil end if attributes.key?(:'dc_points') self.dc_points = attributes[:'dc_points'] else self.dc_points = nil end if attributes.key?(:'endgame_points') self.endgame_points = attributes[:'endgame_points'] else self.endgame_points = nil end if attributes.key?(:'penalty_points_committed') self.penalty_points_committed = attributes[:'penalty_points_committed'] else self.penalty_points_committed = nil end if attributes.key?(:'pre_penalty_total') self.pre_penalty_total = attributes[:'pre_penalty_total'] else self.pre_penalty_total = nil end end |
Instance Attribute Details
#auto_junction_cone_points ⇒ Object
Returns the value of attribute auto_junction_cone_points.
22 23 24 |
# File 'lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb', line 22 def auto_junction_cone_points @auto_junction_cone_points end |
#auto_navigation_points ⇒ Object
Returns the value of attribute auto_navigation_points.
18 19 20 |
# File 'lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb', line 18 def @auto_navigation_points end |
#auto_points ⇒ Object
Returns the value of attribute auto_points.
36 37 38 |
# File 'lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb', line 36 def auto_points @auto_points end |
#auto_terminal_cone_points ⇒ Object
Returns the value of attribute auto_terminal_cone_points.
24 25 26 |
# File 'lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb', line 24 def auto_terminal_cone_points @auto_terminal_cone_points end |
#circuit_points ⇒ Object
Returns the value of attribute circuit_points.
32 33 34 |
# File 'lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb', line 32 def circuit_points @circuit_points end |
#dc_junction_cone_points ⇒ Object
Returns the value of attribute dc_junction_cone_points.
26 27 28 |
# File 'lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb', line 26 def dc_junction_cone_points @dc_junction_cone_points end |
#dc_points ⇒ Object
Returns the value of attribute dc_points.
38 39 40 |
# File 'lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb', line 38 def dc_points @dc_points end |
#dc_terminal_cone_points ⇒ Object
Returns the value of attribute dc_terminal_cone_points.
28 29 30 |
# File 'lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb', line 28 def dc_terminal_cone_points @dc_terminal_cone_points end |
#eg_navigation_points ⇒ Object
Returns the value of attribute eg_navigation_points.
34 35 36 |
# File 'lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb', line 34 def @eg_navigation_points end |
#endgame_points ⇒ Object
Returns the value of attribute endgame_points.
40 41 42 |
# File 'lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb', line 40 def endgame_points @endgame_points end |
#ownership_points ⇒ Object
Returns the value of attribute ownership_points.
30 31 32 |
# File 'lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb', line 30 def ownership_points @ownership_points end |
#penalty_points_committed ⇒ Object
Returns the value of attribute penalty_points_committed.
42 43 44 |
# File 'lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb', line 42 def penalty_points_committed @penalty_points_committed end |
#pre_penalty_total ⇒ Object
Returns the value of attribute pre_penalty_total.
44 45 46 |
# File 'lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb', line 44 def pre_penalty_total @pre_penalty_total end |
#signal_bonus_points ⇒ Object
Returns the value of attribute signal_bonus_points.
20 21 22 |
# File 'lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb', line 20 def signal_bonus_points @signal_bonus_points end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
67 68 69 |
# File 'lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb', line 67 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
72 73 74 |
# File 'lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb', line 72 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb', line 47 def self.attribute_map { :'auto_navigation_points' => :'autoNavigationPoints', :'signal_bonus_points' => :'signalBonusPoints', :'auto_junction_cone_points' => :'autoJunctionConePoints', :'auto_terminal_cone_points' => :'autoTerminalConePoints', :'dc_junction_cone_points' => :'dcJunctionConePoints', :'dc_terminal_cone_points' => :'dcTerminalConePoints', :'ownership_points' => :'ownershipPoints', :'circuit_points' => :'circuitPoints', :'eg_navigation_points' => :'egNavigationPoints', :'auto_points' => :'autoPoints', :'dc_points' => :'dcPoints', :'endgame_points' => :'endgamePoints', :'penalty_points_committed' => :'penaltyPointsCommitted', :'pre_penalty_total' => :'prePenaltyTotal' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 |
# File 'lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb', line 464 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
97 98 99 100 |
# File 'lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb', line 97 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb', line 77 def self.openapi_types { :'auto_navigation_points' => :'Integer', :'signal_bonus_points' => :'Integer', :'auto_junction_cone_points' => :'Integer', :'auto_terminal_cone_points' => :'Integer', :'dc_junction_cone_points' => :'Integer', :'dc_terminal_cone_points' => :'Integer', :'ownership_points' => :'Integer', :'circuit_points' => :'Integer', :'eg_navigation_points' => :'Integer', :'auto_points' => :'Integer', :'dc_points' => :'Integer', :'endgame_points' => :'Integer', :'penalty_points_committed' => :'Integer', :'pre_penalty_total' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 |
# File 'lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb', line 430 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && signal_bonus_points == o.signal_bonus_points && auto_junction_cone_points == o.auto_junction_cone_points && auto_terminal_cone_points == o.auto_terminal_cone_points && dc_junction_cone_points == o.dc_junction_cone_points && dc_terminal_cone_points == o.dc_terminal_cone_points && ownership_points == o.ownership_points && circuit_points == o.circuit_points && == o. && auto_points == o.auto_points && dc_points == o.dc_points && endgame_points == o.endgame_points && penalty_points_committed == o.penalty_points_committed && pre_penalty_total == o.pre_penalty_total end |
#eql?(o) ⇒ Boolean
451 452 453 |
# File 'lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb', line 451 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
457 458 459 |
# File 'lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb', line 457 def hash [, signal_bonus_points, auto_junction_cone_points, auto_terminal_cone_points, dc_junction_cone_points, dc_terminal_cone_points, ownership_points, circuit_points, , auto_points, dc_points, endgame_points, penalty_points_committed, pre_penalty_total].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb', line 205 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @auto_navigation_points.nil? invalid_properties.push('invalid value for "auto_navigation_points", auto_navigation_points cannot be nil.') end if @signal_bonus_points.nil? invalid_properties.push('invalid value for "signal_bonus_points", signal_bonus_points cannot be nil.') end if @auto_junction_cone_points.nil? invalid_properties.push('invalid value for "auto_junction_cone_points", auto_junction_cone_points cannot be nil.') end if @auto_terminal_cone_points.nil? invalid_properties.push('invalid value for "auto_terminal_cone_points", auto_terminal_cone_points cannot be nil.') end if @dc_junction_cone_points.nil? invalid_properties.push('invalid value for "dc_junction_cone_points", dc_junction_cone_points cannot be nil.') end if @dc_terminal_cone_points.nil? invalid_properties.push('invalid value for "dc_terminal_cone_points", dc_terminal_cone_points cannot be nil.') end if @ownership_points.nil? invalid_properties.push('invalid value for "ownership_points", ownership_points cannot be nil.') end if @circuit_points.nil? invalid_properties.push('invalid value for "circuit_points", circuit_points cannot be nil.') end if @eg_navigation_points.nil? invalid_properties.push('invalid value for "eg_navigation_points", eg_navigation_points cannot be nil.') end if @auto_points.nil? invalid_properties.push('invalid value for "auto_points", auto_points cannot be nil.') end if @dc_points.nil? invalid_properties.push('invalid value for "dc_points", dc_points cannot be nil.') end if @endgame_points.nil? invalid_properties.push('invalid value for "endgame_points", endgame_points cannot be nil.') end if @penalty_points_committed.nil? invalid_properties.push('invalid value for "penalty_points_committed", penalty_points_committed cannot be nil.') end if @pre_penalty_total.nil? invalid_properties.push('invalid value for "pre_penalty_total", pre_penalty_total cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
486 487 488 489 490 491 492 493 494 495 496 497 498 |
# File 'lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb', line 486 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/ftc_api_v3_client/models/api_v3_power_play_remote_points_detail.rb', line 269 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @auto_navigation_points.nil? return false if @signal_bonus_points.nil? return false if @auto_junction_cone_points.nil? return false if @auto_terminal_cone_points.nil? return false if @dc_junction_cone_points.nil? return false if @dc_terminal_cone_points.nil? return false if @ownership_points.nil? return false if @circuit_points.nil? return false if @eg_navigation_points.nil? return false if @auto_points.nil? return false if @dc_points.nil? return false if @endgame_points.nil? return false if @penalty_points_committed.nil? return false if @pre_penalty_total.nil? true end |