Class: FtcApiV3Client::ApiV3TeamHistory
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FtcApiV3Client::ApiV3TeamHistory
- Defined in:
- lib/ftc_api_v3_client/models/api_v3_team_history.rb
Instance Attribute Summary collapse
-
#affiliations ⇒ Object
Returns the value of attribute affiliations.
-
#city ⇒ Object
Returns the value of attribute city.
-
#coordinates ⇒ Object
Coordinates are for the team's city.
-
#country ⇒ Object
Returns the value of attribute country.
-
#display_number ⇒ Object
Use this for presentation purposes; it may include a shorter representation of the official team number for some teams in some seasons.
-
#name ⇒ Object
Returns the value of attribute name.
-
#number ⇒ Object
Returns the value of attribute number.
-
#rookie_cmp_year ⇒ Object
Returns the value of attribute rookie_cmp_year.
-
#seasons ⇒ Object
Returns the value of attribute seasons.
-
#state_prov ⇒ Object
Returns the value of attribute state_prov.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApiV3TeamHistory
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ApiV3TeamHistory
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/ftc_api_v3_client/models/api_v3_team_history.rb', line 97 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FtcApiV3Client::ApiV3TeamHistory` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FtcApiV3Client::ApiV3TeamHistory`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'number') self.number = attributes[:'number'] else self.number = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'affiliations') self.affiliations = attributes[:'affiliations'] else self.affiliations = nil end if attributes.key?(:'city') self.city = attributes[:'city'] end if attributes.key?(:'state_prov') self.state_prov = attributes[:'state_prov'] end if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'rookie_cmp_year') self.rookie_cmp_year = attributes[:'rookie_cmp_year'] else self.rookie_cmp_year = nil end if attributes.key?(:'seasons') if (value = attributes[:'seasons']).is_a?(Array) self.seasons = value end else self.seasons = nil end if attributes.key?(:'display_number') self.display_number = attributes[:'display_number'] else self.display_number = nil end if attributes.key?(:'coordinates') self.coordinates = attributes[:'coordinates'] end end |
Instance Attribute Details
#affiliations ⇒ Object
Returns the value of attribute affiliations.
22 23 24 |
# File 'lib/ftc_api_v3_client/models/api_v3_team_history.rb', line 22 def affiliations @affiliations end |
#city ⇒ Object
Returns the value of attribute city.
24 25 26 |
# File 'lib/ftc_api_v3_client/models/api_v3_team_history.rb', line 24 def city @city end |
#coordinates ⇒ Object
Coordinates are for the team's city
38 39 40 |
# File 'lib/ftc_api_v3_client/models/api_v3_team_history.rb', line 38 def coordinates @coordinates end |
#country ⇒ Object
Returns the value of attribute country.
28 29 30 |
# File 'lib/ftc_api_v3_client/models/api_v3_team_history.rb', line 28 def country @country end |
#display_number ⇒ Object
Use this for presentation purposes; it may include a shorter representation of the official team number for some teams in some seasons.
35 36 37 |
# File 'lib/ftc_api_v3_client/models/api_v3_team_history.rb', line 35 def display_number @display_number end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/ftc_api_v3_client/models/api_v3_team_history.rb', line 20 def name @name end |
#number ⇒ Object
Returns the value of attribute number.
18 19 20 |
# File 'lib/ftc_api_v3_client/models/api_v3_team_history.rb', line 18 def number @number end |
#rookie_cmp_year ⇒ Object
Returns the value of attribute rookie_cmp_year.
30 31 32 |
# File 'lib/ftc_api_v3_client/models/api_v3_team_history.rb', line 30 def rookie_cmp_year @rookie_cmp_year end |
#seasons ⇒ Object
Returns the value of attribute seasons.
32 33 34 |
# File 'lib/ftc_api_v3_client/models/api_v3_team_history.rb', line 32 def seasons @seasons end |
#state_prov ⇒ Object
Returns the value of attribute state_prov.
26 27 28 |
# File 'lib/ftc_api_v3_client/models/api_v3_team_history.rb', line 26 def state_prov @state_prov end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/ftc_api_v3_client/models/api_v3_team_history.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/ftc_api_v3_client/models/api_v3_team_history.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/ftc_api_v3_client/models/api_v3_team_history.rb', line 41 def self.attribute_map { :'number' => :'number', :'name' => :'name', :'affiliations' => :'affiliations', :'city' => :'city', :'state_prov' => :'stateProv', :'country' => :'country', :'rookie_cmp_year' => :'rookieCmpYear', :'seasons' => :'seasons', :'display_number' => :'displayNumber', :'coordinates' => :'coordinates' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/ftc_api_v3_client/models/api_v3_team_history.rb', line 243 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/ftc_api_v3_client/models/api_v3_team_history.rb', line 83 def self.openapi_nullable Set.new([ :'number', :'name', :'affiliations', :'city', :'state_prov', :'country', :'display_number', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/ftc_api_v3_client/models/api_v3_team_history.rb', line 67 def self.openapi_types { :'number' => :'String', :'name' => :'String', :'affiliations' => :'String', :'city' => :'String', :'state_prov' => :'String', :'country' => :'String', :'rookie_cmp_year' => :'Integer', :'seasons' => :'Array<ApiV3TeamSeasonHistory>', :'display_number' => :'String', :'coordinates' => :'ApiV3Coordinates' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/ftc_api_v3_client/models/api_v3_team_history.rb', line 213 def ==(o) return true if self.equal?(o) self.class == o.class && number == o.number && name == o.name && affiliations == o.affiliations && city == o.city && state_prov == o.state_prov && country == o.country && rookie_cmp_year == o.rookie_cmp_year && seasons == o.seasons && display_number == o.display_number && coordinates == o.coordinates end |
#eql?(o) ⇒ Boolean
230 231 232 |
# File 'lib/ftc_api_v3_client/models/api_v3_team_history.rb', line 230 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
236 237 238 |
# File 'lib/ftc_api_v3_client/models/api_v3_team_history.rb', line 236 def hash [number, name, affiliations, city, state_prov, country, rookie_cmp_year, seasons, display_number, coordinates].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/ftc_api_v3_client/models/api_v3_team_history.rb', line 168 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @rookie_cmp_year.nil? invalid_properties.push('invalid value for "rookie_cmp_year", rookie_cmp_year cannot be nil.') end if @seasons.nil? invalid_properties.push('invalid value for "seasons", seasons cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/ftc_api_v3_client/models/api_v3_team_history.rb', line 265 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
184 185 186 187 188 189 |
# File 'lib/ftc_api_v3_client/models/api_v3_team_history.rb', line 184 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @rookie_cmp_year.nil? return false if @seasons.nil? true end |